from faker.typing import Country

from .. import Provider as DateTimeProvider


class Provider(DateTimeProvider):
    DAY_NAMES = {
        "0": "السبت",
        "1": "الأحد",
        "2": "الإثنين",
        "3": "الثلاثاء",
        "4": "الأربعاء",
        "5": "الخميس",
        "6": "الجمعة",
    }

    MONTH_NAMES = {
        "01": "كانون الثّاني",
        "02": "شباط",
        "03": "آذار",
        "04": "نيسان",
        "05": "أيّار",
        "06": "حزيران",
        "07": "تمّوز",
        "08": "آب",
        "09": "أيلول",
        "10": "تشرين الأول",
        "11": "تشرين الثاني",
        "12": "كانون الأول",
    }

    centuries = [
        "الأول",
        "الثاني",
        "الثالث",
        "الرابع",
        "الخامس",
        "السادس",
        "السابع",
        "الثامن",
        "التاسع",
        "العاشر",
        "الحادي عشر",
        "الثاني عشر",
        "الثالث عشر",
        "الرابع عشر",
        "الخامس عشر",
        "السادس عشر",
        "الثامن عشر",
        "التاسع عشر",
        "العشرين",
        "الحادي والعشرين",
        "الثاني والعشرين",
    ]

    countries = [
        Country(
            timezones=["أوروب/أندورا"],
            alpha_2_code="AD",
            alpha_3_code="AND",
            continent="أوروبا",
            name="أندورا",
            capital="أندورا لا فيلا",
        ),
        Country(
            timezones=["آسيا/كابل"],
            alpha_2_code="AF",
            alpha_3_code="AFG",
            continent="آسيا",
            name="أفغانستان",
            capital="كابل",
        ),
        Country(
            timezones=["أمريكا/أنتيغوا"],
            alpha_2_code="AG",
            alpha_3_code="ATG",
            continent="أمريكا الشمالية",
            name="أنتيغوا وباربودا",
            capital="سانت جونز",
        ),
        Country(
            timezones=["أوروبا/تيرانا"],
            alpha_2_code="AL",
            alpha_3_code="ALB",
            continent="أوروبا",
            name="ألبانيا",
            capital="تيرانا",
        ),
        Country(
            timezones=["آسيا/يريفان"],
            alpha_2_code="AM",
            alpha_3_code="ARM",
            continent="آسيا",
            name="أرمينيا",
            capital="يريفان",
        ),
        Country(
            timezones=["إفريقيا/لواندا"],
            alpha_2_code="AO",
            alpha_3_code="AGO",
            continent="إفريقيا",
            name="أنغولا",
            capital="لواندا",
        ),
        Country(
            timezones=[
                "أمريكا/الأرجنتين/بوينس_آيرس",
                "أمريكا/الأرجنتين/Cordoba",
                "أمريكا/الأرجنتين/خوخوي",
                "أمريكا/الأرجنتين/توكومان",
                "أمريكا/الأرجنتين/كاتاماركا",
                "أمريكا/الأرجنتين/لا_ريوخا",
                "أمريكا/الأرجنتين/سان_خوان",
                "أمريكا/الأرجنتين/مندوزا",
                "أمريكا/الأرجنتين/ريو_غاليغوس",
                "أمريكا/الأرجنتين/أوشوايا",
            ],
            alpha_2_code="AR",
            alpha_3_code="ARG",
            continent="أمريكا الجنوبية",
            name="الأرجنتين",
            capital="بوينس آيرس",
        ),
        Country(
            timezones=["أوروبا/النمسا"],
            alpha_2_code="AT",
            alpha_3_code="AUT",
            continent="أوروبا",
            name="النمسا",
            capital="فيينا",
        ),
        Country(
            timezones=[
                "أستراليا/لورد_هاو",
                "أستراليا/هوبارت",
                "أستراليا/كري",
                "أستراليا/ملبورن",
                "أستراليا/سدني",
                "أستراليا/بروكن_هل",
                "أستراليا/بريزبن",
                "أستراليا/ليندمان",
                "أستراليا/أديلايد",
                "أستراليا/داروين",
                "أستراليا/برث",
            ],
            alpha_2_code="AU",
            alpha_3_code="AUS",
            continent="أوقيانوسيا",
            name="أستراليا",
            capital="كانبرا",
        ),
        Country(
            timezones=["آسيا/باكو"],
            alpha_2_code="AZ",
            alpha_3_code="AZE",
            continent="آسيا",
            name="أذربيجان",
            capital="باكو",
        ),
        Country(
            timezones=["أمريكا/باربادوس"],
            alpha_2_code="BB",
            alpha_3_code="BRB",
            continent="أمريكا الشمالية",
            name="باربادوس",
            capital="بريدج تاون",
        ),
        Country(
            timezones=["آسيا/دكا"],
            alpha_2_code="BD",
            alpha_3_code="BGD",
            continent="آسيا",
            name="بنغلادش",
            capital="دكا",
        ),
        Country(
            timezones=["أوروبا/بروكسل"],
            alpha_2_code="BE",
            alpha_3_code="BEL",
            continent="أوروبا",
            name="بلجيكا",
            capital="بروكسل",
        ),
        Country(
            timezones=["إفريقيا/واغادوغو"],
            alpha_2_code="BF",
            alpha_3_code="BFA",
            continent="إفريقيا",
            name="بوركينا فاسو",
            capital="واغادوغو",
        ),
        Country(
            timezones=["أوروبا/صوفيا"],
            alpha_2_code="BG",
            alpha_3_code="BGR",
            continent="أوروبا",
            name="بلغاريا",
            capital="صوفيا",
        ),
        Country(
            timezones=["آسيا/البحرين"],
            alpha_2_code="BH",
            alpha_3_code="BHR",
            continent="آسيا",
            name="البحرين",
            capital="المنامة",
        ),
        Country(
            timezones=["إفريقيا/بوجمبورا"],
            alpha_2_code="BI",
            alpha_3_code="BDI",
            continent="إفريقيا",
            name="بوروندي",
            capital="بوجمبورا",
        ),
        Country(
            timezones=["إفريقيا/بورتو نوفو"],
            alpha_2_code="BJ",
            alpha_3_code="BEN",
            continent="إفريقيا",
            name="بنين",
            capital="بورتو نوفو",
        ),
        Country(
            timezones=["آسيا/بروناي"],
            alpha_2_code="BN",
            alpha_3_code="BRN",
            continent="آسيا",
            name="اتحاد بروناي (دار السلام)",
            capital="بندر سري بكاوان",
        ),
        Country(
            timezones=["أمريكا/لاباز"],
            alpha_2_code="BO",
            alpha_3_code="BOL",
            continent="أمريكا الجنوبية",
            name="بوليفيا",
            capital="سوكري",
        ),
        Country(
            timezones=[
                "أمريكا/نورونها",
                "أمريكا/بليم",
                "أمريكا/فورتاليزا",
                "أمريكا/ريسيفي",
                "أمريكا/أراغوينا",
                "أمريكا/ماسايو",
                "أمريكا/باهيا",
                "أمريكا/ساو_باولو",
                "أمريكا/كامبو_غراندي",
                "أمريكا/كويابا",
                "أمريكا/بورتو_فاليو",
                "أمريكا/بوا_فيستا",
                "أمريكا/ماناوس",
                "أمريكا/إيرونيبي",
                "أمريكا/ريو_برانكو",
            ],
            alpha_2_code="BR",
            alpha_3_code="BRA",
            continent="أمريكا الجنوبية",
            name="البرازيل",
            capital="برازيليا",
        ),
        Country(
            timezones=["أمريكا/ناساو"],
            alpha_2_code="BS",
            alpha_3_code="BHS",
            continent="أمريكا الشمالية",
            name="باهاماس",
            capital="ناساو",
        ),
        Country(
            timezones=["آسيا/تيمفو"],
            alpha_2_code="BT",
            alpha_3_code="BTN",
            continent="آسيا",
            name="بوتان",
            capital="تيمفو",
        ),
        Country(
            timezones=["إفريقيا/غابورون"],
            alpha_2_code="BW",
            alpha_3_code="BWA",
            continent="إفريقيا",
            name="بوتسوانا",
            capital="غابورون",
        ),
        Country(
            timezones=["أوروبا/مينسك"],
            alpha_2_code="BY",
            alpha_3_code="BLR",
            continent="أوروبا",
            name="روسيا البيضاء",
            capital="مينسك",
        ),
        Country(
            timezones=["أمريكا/بليز"],
            alpha_2_code="BZ",
            alpha_3_code="BLZ",
            continent="أمريكا الشمالية",
            name="بليز",
            capital="بلموبان",
        ),
        Country(
            timezones=[
                "أمريكا/سينت_جونز",
                "أمريكا/هاليفاكس",
                "أمريكا/جليس_باي",
                "أمريكا/مونكتون",
                "أمريكا/جووس_باي",
                "أمريكا/بلانك_سابلون",
                "أمريكا/مونتريال",
                "أمريكا/تورونتو",
                "أمريكا/نيبيغون",
                "أمريكا/ثاندر_باي",
                "أمريكا/بانغيرتانغ",
                "أمريكا/إيكواليوت",
                "أمريكا/أتيكوكان",
                "أمريكا/رانكن_إنلت",
                "أمريكا/وينيبيغ",
                "أمريكا/رايني_ريفر",
                "أمريكا/كامبريدج_باي",
                "أمريكا/ريجينا",
                "أمريكا/سويفت_كارنت",
                "أمريكا/إدمونتون",
                "أمريكا/يلو_نايف",
                "أمريكا/إنوفك",
                "أمريكا/دوسن_كريك",
                "أمريكا/فانكوفر",
                "أمريكا/وايت_هورس",
                "أمريكا/داوسون",
            ],
            alpha_2_code="CA",
            alpha_3_code="CAN",
            continent="أمريكا الشمالية",
            name="كندا",
            capital="أوتاوا",
        ),
        Country(
            timezones=["إفريقيا/كينشاسا", "إفريقيا/لوبومباشي"],
            alpha_2_code="CD",
            alpha_3_code="COD",
            continent="إفريقيا",
            name="جمهورية الكونغو الديمقراطية",
            capital="كينشاسا",
        ),
        Country(
            timezones=["إفريقيا/برازافيل"],
            alpha_2_code="CG",
            alpha_3_code="COG",
            continent="إفريقيا",
            name="جمهورية الكونغو",
            capital="برازافيل",
        ),
        Country(
            timezones=["إفريقيا/أبيدجان"],
            alpha_2_code="CI",
            alpha_3_code="CIV",
            continent="إفريقيا",
            name="ساحل العاج",
            capital="ياموسوكرو",
        ),
        Country(
            timezones=["أمريكا/سانتياغو", "المحيط_الهاديء/جزيرة_القيامة"],
            alpha_2_code="CL",
            alpha_3_code="CHL",
            continent="أمريكا الجنوبية",
            name="تشيلي",
            capital="سانتياغو",
        ),
        Country(
            timezones=["إفريقيا/دوالا"],
            alpha_2_code="CM",
            alpha_3_code="CMR",
            continent="إفريقيا",
            name="الكاميرون",
            capital="ياوندي",
        ),
        Country(
            timezones=[
                "آسيا/شانغهاي",
                "آسيا/هاربن",
                "آسيا/تشونغتشينغ",
                "آسيا/أورومتشي",
                "آسيا/كاشغر",
            ],
            alpha_2_code="CN",
            alpha_3_code="CHN",
            continent="آسيا",
            name="جمهورية الصين الشعبية",
            capital="بكين",
        ),
        Country(
            timezones=["أمريكا/بوغوتا"],
            alpha_2_code="CO",
            alpha_3_code="COL",
            continent="أمريكا الجنوبية",
            name="كولومبيا",
            capital="بوغوتا",
        ),
        Country(
            timezones=["أمريكا/كوستاريكا"],
            alpha_2_code="CR",
            alpha_3_code="CRI",
            continent="أمريكا الشمالية",
            name="كوستاريكا",
            capital="سان خوسيه",
        ),
        Country(
            timezones=["أمريكا/هافانا"],
            alpha_2_code="CU",
            alpha_3_code="CUB",
            continent="أمريكا الشمالية",
            name="كوبا",
            capital="هافانا",
        ),
        Country(
            timezones=["الأطلنطي/الرأس_الأخضر"],
            alpha_2_code="CV",
            alpha_3_code="CPV",
            continent="إفريقيا",
            name="جمهورية الرأس الأخضر",
            capital="برايا",
        ),
        Country(
            timezones=["آسيا/نيقوسيا"],
            alpha_2_code="CY",
            alpha_3_code="CYP",
            continent="آسيا",
            name="قبرص",
            capital="نيقوسيا",
        ),
        Country(
            timezones=["أوروبا/براغ"],
            alpha_2_code="CZ",
            alpha_3_code="CZE",
            continent="أوروبا",
            name="جمهورية التشيك",
            capital="براغ",
        ),
        Country(
            timezones=["أوروبا/برلين"],
            alpha_2_code="DE",
            alpha_3_code="DEU",
            continent="أوروبا",
            name="ألمانيا",
            capital="برلين",
        ),
        Country(
            timezones=["إفريقيا/جيبوتي"],
            alpha_2_code="DJ",
            alpha_3_code="DJI",
            continent="إفريقيا",
            name="جيبوتي",
            capital="جيبوتي",
        ),
        Country(
            timezones=["أوروبا/كوبنهاغن"],
            alpha_2_code="DK",
            alpha_3_code="DNK",
            continent="أوروبا",
            name="الدنمارك",
            capital="كوبنهاغن",
        ),
        Country(
            timezones=["أمريكا/دومينيكا"],
            alpha_2_code="DM",
            alpha_3_code="DMA",
            continent="أمريكا الشمالية",
            name="دومينيكا",
            capital="روسياو",
        ),
        Country(
            timezones=["أمريكا/سانتو_دومينغو"],
            alpha_2_code="DO",
            alpha_3_code="DOM",
            continent="أمريكا الشمالية",
            name="جمهورية الدومينيكان",
            capital="سانتو دومينغو",
        ),
        Country(
            timezones=["أمريكا/غواياكيل", "المحيط_الهاديء/أرخبيل_غالاباغوس"],
            alpha_2_code="EC",
            alpha_3_code="ECU",
            continent="أمريكا الجنوبية",
            name="الإكوادور",
            capital="كيتو",
        ),
        Country(
            timezones=["أوروبا/تالين"],
            alpha_2_code="EE",
            alpha_3_code="EST",
            continent="أوروبا",
            name="إستونيا",
            capital="تالين",
        ),
        Country(
            timezones=["إفريقيا/القاهرة"],
            alpha_2_code="EG",
            alpha_3_code="EGY",
            continent="إفريقيا",
            name="مصر",
            capital="القاهرة",
        ),
        Country(
            timezones=["إفريقيا/أسمرة"],
            alpha_2_code="ER",
            alpha_3_code="ERI",
            continent="إفريقيا",
            name="إرتيريا",
            capital="أسمرة",
        ),
        Country(
            timezones=["إفريقيا/أديس أبابا"],
            alpha_2_code="ET",
            alpha_3_code="ETH",
            continent="إفريقيا",
            name="إثيوبيا",
            capital="أديس أبابا",
        ),
        Country(
            timezones=["أوروبا/هلسنكي"],
            alpha_2_code="FI",
            alpha_3_code="FIN",
            continent="أوروبا",
            name="فنلندا",
            capital="هلسنكي",
        ),
        Country(
            timezones=["المحيط_الهاديء/فيجي"],
            alpha_2_code="FJ",
            alpha_3_code="FJI",
            continent="أوقيانوسيا",
            name="فيجي",
            capital="سوفا",
        ),
        Country(
            timezones=["أوروبا/باريس"],
            alpha_2_code="FR",
            alpha_3_code="FRA",
            continent="أوروبا",
            name="فرنسا",
            capital="باريس",
        ),
        Country(
            timezones=["إفريقيا/ليبرفيل"],
            alpha_2_code="GA",
            alpha_3_code="GAB",
            continent="إفريقيا",
            name="الغابون",
            capital="ليبرفيل",
        ),
        Country(
            timezones=["آسيا/تبليسي"],
            alpha_2_code="GE",
            alpha_3_code="GEO",
            continent="آسيا",
            name="جورجيا",
            capital="تبليسي",
        ),
        Country(
            timezones=["إفريقيا/أكرا"],
            alpha_2_code="GH",
            alpha_3_code="GHA",
            continent="إفريقيا",
            name="غانا",
            capital="أكرا",
        ),
        Country(
            timezones=["إفريقيا/بانجول"],
            alpha_2_code="GM",
            alpha_3_code="GMB",
            continent="إفريقيا",
            name="غامبيا",
            capital="بانجول",
        ),
        Country(
            timezones=["إفريقيا/كوناكري"],
            alpha_2_code="GN",
            alpha_3_code="GIN",
            continent="إفريقيا",
            name="غينيا",
            capital="كوناكري",
        ),
        Country(
            timezones=["أوروبا/أثينا"],
            alpha_2_code="GR",
            alpha_3_code="GRC",
            continent="أوروبا",
            name="اليونان",
            capital="أثينا",
        ),
        Country(
            timezones=["أمريكا/غواتيمالا"],
            alpha_2_code="GT",
            alpha_3_code="GTM",
            continent="أمريكا الشمالية",
            name="غواتيمالا",
            capital="غواتيمالا سيتي",
        ),
        Country(
            timezones=["أمريكا/غواتيمالا"],
            alpha_2_code="HT",
            alpha_3_code="HTI",
            continent="أمريكا الشمالية",
            name="هايتي",
            capital="بورت أو برانس",
        ),
        Country(
            timezones=["إفريقيا/بيساو"],
            alpha_2_code="GW",
            alpha_3_code="GNB",
            continent="إفريقيا",
            name="غينيا بيساو",
            capital="بيساو",
        ),
        Country(
            timezones=["أمريكا/غيانا"],
            alpha_2_code="GY",
            alpha_3_code="GUY",
            continent="أمريكا الجنوبية",
            name="غيانا",
            capital="جورج تاون",
        ),
        Country(
            timezones=["أمريكا/تيجوسيجالبا"],
            alpha_2_code="HN",
            alpha_3_code="HND",
            continent="أمريكا الشمالية",
            name="هندوراس",
            capital="تيجوسيجالبا",
        ),
        Country(
            timezones=["أوروبا/بودابست"],
            alpha_2_code="HU",
            alpha_3_code="HUN",
            continent="أوروبا",
            name="هنغاريا",
            capital="بودابست",
        ),
        Country(
            timezones=[
                "آسيا/جاكرتا",
                "آسيا/بونتياناك",
                "آسيا/ماكاسار",
                "آسيا/جايابورا",
            ],
            alpha_2_code="ID",
            alpha_3_code="IDN",
            continent="آسيا",
            name="إندونسيا",
            capital="جاكرتا",
        ),
        Country(
            timezones=["أوروبا/دبلن"],
            alpha_2_code="IE",
            alpha_3_code="IRL",
            continent="أوروبا",
            name="إيرلندا",
            capital="دبلن",
        ),
        Country(
            timezones=["آسيا/القدس"],
            alpha_2_code="IL",
            alpha_3_code="ISR",
            continent="آسيا",
            name="فلسطين",
            capital="القدس",
        ),
        Country(
            timezones=["آسيا/كالكتا"],
            alpha_2_code="IN",
            alpha_3_code="IND",
            continent="آسيا",
            name="الهند",
            capital="نيو دلهي",
        ),
        Country(
            timezones=["آسيا/بغداد"],
            alpha_2_code="IQ",
            alpha_3_code="IRQ",
            continent="آسيا",
            name="العراق",
            capital="بغداد",
        ),
        Country(
            timezones=["آسيا/طهران"],
            alpha_2_code="IR",
            alpha_3_code="IRN",
            continent="آسيا",
            name="إيران",
            capital="طهران",
        ),
        Country(
            timezones=["الأطلنطي/ريكيافيك"],
            alpha_2_code="IS",
            alpha_3_code="ISL",
            continent="أوروبا",
            name="آيسلندا",
            capital="ريكيافيك",
        ),
        Country(
            timezones=["أوروبا/روما"],
            alpha_2_code="IT",
            alpha_3_code="ITA",
            continent="أوروبا",
            name="إيطاليا",
            capital="روما",
        ),
        Country(
            timezones=["أمريكا/جامايكا"],
            alpha_2_code="JM",
            alpha_3_code="JAM",
            continent="أمريكا الشمالية",
            name="جامايكا",
            capital="كينغستون",
        ),
        Country(
            timezones=["آسيا/عمّان"],
            alpha_2_code="JO",
            alpha_3_code="JOR",
            continent="آسيا",
            name="الأردن",
            capital="عمّان",
        ),
        Country(
            timezones=["آسيا/طوكيو"],
            alpha_2_code="JP",
            alpha_3_code="JPN",
            continent="آسيا",
            name="اليابان",
            capital="طوكيو",
        ),
        Country(
            timezones=["إفريقيا/نيروبي"],
            alpha_2_code="KE",
            alpha_3_code="KEN",
            continent="إفريقيا",
            name="كينيا",
            capital="نيروبي",
        ),
        Country(
            timezones=["آسيا/بشكيك"],
            alpha_2_code="KG",
            alpha_3_code="KGZ",
            continent="آسيا",
            name="قيرغيزستان",
            capital="بشكيك",
        ),
        Country(
            timezones=[
                "المحيط_الهاديء/تاراوا",
                "المحيط_الهاديء/إيديربيري",
                "المحيط_الهاديء/كريتيماتي",
            ],
            alpha_2_code="KI",
            alpha_3_code="KIR",
            continent="أوقيانوسيا",
            name="كيريباتي",
            capital="جنوب تاراوا",
        ),
        Country(
            timezones=["آسيا/بيونغ_يانغ"],
            alpha_2_code="KP",
            alpha_3_code="PRK",
            continent="آسيا",
            name="كوريا الشمالية",
            capital="بيونغ يانغ",
        ),
        Country(
            timezones=["آسيا/سيؤول"],
            alpha_2_code="KR",
            alpha_3_code="KOR",
            continent="آسيا",
            name="؛كوريا الجنوبية",
            capital="سيؤول",
        ),
        Country(
            timezones=["آسيا/الكويت"],
            alpha_2_code="KW",
            alpha_3_code="KWT",
            continent="آسيا",
            name="الكويت",
            capital="الكويت",
        ),
        Country(
            timezones=["آسيا/بيروت"],
            alpha_2_code="LB",
            alpha_3_code="LBN",
            continent="آسيا",
            name="لبنان",
            capital="بيروت",
        ),
        Country(
            timezones=["أوروبا/فادوز"],
            alpha_2_code="LI",
            alpha_3_code="LIE",
            continent="أوروبا",
            name="ليختنشتاين",
            capital="فادوز",
        ),
        Country(
            timezones=["إفريقيا/مونروفيا"],
            alpha_2_code="LR",
            alpha_3_code="LBR",
            continent="إفريقيا",
            name="ليبيريا",
            capital="مونروفيا",
        ),
        Country(
            timezones=["إفريقيا/ماسيرو"],
            alpha_2_code="LS",
            alpha_3_code="LSO",
            continent="إفريقيا",
            name="ليسوتو",
            capital="ماسيرو",
        ),
        Country(
            timezones=["أوروبا/فيلنيوس"],
            alpha_2_code="LT",
            alpha_3_code="LTU",
            continent="أوروبا",
            name="ليتوانيا",
            capital="فيلنيوس",
        ),
        Country(
            timezones=["أوروبا/لوكسمبرغ"],
            alpha_2_code="LU",
            alpha_3_code="LUX",
            continent="أوروبا",
            name="لوكسمبرغ",
            capital="لوكسمبرغ سيتي",
        ),
        Country(
            timezones=["أوروبا/ربيغ"],
            alpha_2_code="LV",
            alpha_3_code="LVA",
            continent="أوروبا",
            name="لاتفيا",
            capital="ربيغ",
        ),
        Country(
            timezones=["إفريقيا/طرابلس"],
            alpha_2_code="LY",
            alpha_3_code="LBY",
            continent="إفريقيا",
            name="ليبيا",
            capital="طرابلس",
        ),
        Country(
            timezones=["الهندي/أنتاناناريفو"],
            alpha_2_code="MG",
            alpha_3_code="MDG",
            continent="إفريقيا",
            name="مدغشقر",
            capital="أنتاناناريفو",
        ),
        Country(
            timezones=["المحيط_الهاديء/ماجورو", "المحيط_الهاديء/كواجلين_أتول"],
            alpha_2_code="MH",
            alpha_3_code="MHL",
            continent="أوقيانوسيا",
            name="جزر مارشال",
            capital="ماجورو",
        ),
        Country(
            timezones=["أوروبا/سكوبيه"],
            alpha_2_code="MK",
            alpha_3_code="MKD",
            continent="أوروبا",
            name="جمهورية مقدونيا",
            capital="سكوبيه",
        ),
        Country(
            timezones=["إفريقيا/باماكو"],
            alpha_2_code="ML",
            alpha_3_code="MLI",
            continent="إفريقيا",
            name="مالي",
            capital="باماكو",
        ),
        Country(
            timezones=["آسيا/رانغون"],
            alpha_2_code="MM",
            alpha_3_code="MMR",
            continent="آسيا",
            name="ميانمار",
            capital="نايبيداو",
        ),
        Country(
            timezones=["آسيا/أولان_باتور", "آسيا/Hovd", "آسيا/تشويبالسان"],
            alpha_2_code="MN",
            alpha_3_code="MNG",
            continent="آسيا",
            name="مانغوليا",
            capital="أولان باتور",
        ),
        Country(
            timezones=["إفريقيا/نواكشط"],
            alpha_2_code="MR",
            alpha_3_code="MRT",
            continent="إفريقيا",
            name="موريتانيا",
            capital="نواكشط",
        ),
        Country(
            timezones=["أوروبا/مالطا"],
            alpha_2_code="MT",
            alpha_3_code="MLT",
            continent="أوروبا",
            name="مالطا",
            capital="فاليتا",
        ),
        Country(
            timezones=["الهندي/موريشيوس"],
            alpha_2_code="MU",
            alpha_3_code="MUS",
            continent="إفريقيا",
            name="موريشيوس",
            capital="بور لويس",
        ),
        Country(
            timezones=["الهندي/جزر_المالديف"],
            alpha_2_code="MV",
            alpha_3_code="MDV",
            continent="آسيا",
            name="جمهورية المالديف",
            capital="ماليه",
        ),
        Country(
            timezones=["إفريقيا/بلانتاير"],
            alpha_2_code="MW",
            alpha_3_code="MWI",
            continent="إفريقيا",
            name="ملاوي",
            capital="ليلونغوي",
        ),
        Country(
            timezones=[
                "أمريكا/ميكسيكو_سيتي",
                "أمريكا/كانكون",
                "أمريكا/ميرديا",
                "أمريكا/مونتيري",
                "أمريكا/مازاتلان",
                "أمريكا/شيواوا",
                "أمريكا/ارموسييو_سونورا",
                "أمريكا/تيخوانا",
            ],
            alpha_2_code="MX",
            alpha_3_code="MEX",
            continent="أمريكا الشمالية",
            name="المكسيك",
            capital="ميكسيكو سيتي§",
        ),
        Country(
            timezones=["آسيا/كوالا_لامبور", "آسيا/Kuching"],
            alpha_2_code="MY",
            alpha_3_code="MYS",
            continent="آسيا",
            name="ماليزيا",
            capital="كوالا لامبور",
        ),
        Country(
            timezones=["إفريقيا/مابوتو"],
            alpha_2_code="MZ",
            alpha_3_code="MOZ",
            continent="إفريقيا",
            name="موزمبيق",
            capital="مابوتو",
        ),
        Country(
            timezones=["إفريقيا/ويندهوك"],
            alpha_2_code="NA",
            alpha_3_code="NAM",
            continent="إفريقيا",
            name="ناميبيا",
            capital="ويندهوك",
        ),
        Country(
            timezones=["إفريقيا/نيامي"],
            alpha_2_code="NE",
            alpha_3_code="NER",
            continent="إفريقيا",
            name="النيجر",
            capital="نيامي",
        ),
        Country(
            timezones=["إفريقيا/لاغوس"],
            alpha_2_code="NG",
            alpha_3_code="NGA",
            continent="إفريقيا",
            name="نيجيريا",
            capital="أبوجا",
        ),
        Country(
            timezones=["أمريكا/ماناغوا"],
            alpha_2_code="NI",
            alpha_3_code="NIC",
            continent="أمريكا الشمالية",
            name="نيكاراغوا",
            capital="ماناغوا",
        ),
        Country(
            timezones=["أوروبا/أمستردام"],
            alpha_2_code="NL",
            alpha_3_code="NLD",
            continent="أوروبا",
            name="هولندا",
            capital="أمستردام",
        ),
        Country(
            timezones=["أوروبا/أوسلو"],
            alpha_2_code="NO",
            alpha_3_code="NOR",
            continent="أوروبا",
            name="النرويج",
            capital="أوسلو",
        ),
        Country(
            timezones=["آسيا/كاتماندو"],
            alpha_2_code="NP",
            alpha_3_code="NPL",
            continent="آسيا",
            name="النيبال",
            capital="كاتماندو",
        ),
        Country(
            timezones=["المحيط_الهاديء/ناورو"],
            alpha_2_code="NR",
            alpha_3_code="NRU",
            continent="أوقيانوسيا",
            name="ناورو",
            capital="يارين",
        ),
        Country(
            timezones=["المحيط_الهاديء/أوكلاند", "المحيط_الهاديء/تشاتهام"],
            alpha_2_code="NZ",
            alpha_3_code="NZL",
            continent="أوقيانوسيا",
            name="نيوزيلاندا",
            capital="ويلينغتون",
        ),
        Country(
            timezones=["آسيا/مسقط"],
            alpha_2_code="OM",
            alpha_3_code="OMN",
            continent="آسيا",
            name="عمان",
            capital="مسقط",
        ),
        Country(
            timezones=["أمريكا/بنما"],
            alpha_2_code="PA",
            alpha_3_code="PAN",
            continent="أمريكا الشمالية",
            name="بنما",
            capital="بنما",
        ),
        Country(
            timezones=["أمريكا/ليما"],
            alpha_2_code="PE",
            alpha_3_code="PER",
            continent="أمريكا الجنوبية",
            name="البيرو",
            capital="ليما",
        ),
        Country(
            timezones=["المحيط_الهاديء/بورت_مورسبي"],
            alpha_2_code="PG",
            alpha_3_code="PNG",
            continent="أوقيانوسيا",
            name="بابوا غينيا الجديدة",
            capital="بورت مورسبي",
        ),
        Country(
            timezones=["آسيا/مانيلا"],
            alpha_2_code="PH",
            alpha_3_code="PHL",
            continent="آسيا",
            name="الفيليبين",
            capital="مانيلا",
        ),
        Country(
            timezones=["آسيا/كاراتشي"],
            alpha_2_code="PK",
            alpha_3_code="PAK",
            continent="آسيا",
            name="باكستان",
            capital="إسلام أباد",
        ),
        Country(
            timezones=["أوروبا/وارسو"],
            alpha_2_code="PL",
            alpha_3_code="POL",
            continent="أوروبا",
            name="بولندا",
            capital="وارسو",
        ),
        Country(
            timezones=["أوروبا/لشبونة", "الأطلنطي/ماديرا", "الأطلنطي/الأزور"],
            alpha_2_code="PT",
            alpha_3_code="PRT",
            continent="أوروبا",
            name="البرتغال",
            capital="لشبونة",
        ),
        Country(
            timezones=["المحيط_الهاديء/بالاو"],
            alpha_2_code="PW",
            alpha_3_code="PLW",
            continent="أوقيانوسيا",
            name="بالاو",
            capital="نجيرولمد",
        ),
        Country(
            timezones=["أمريكا/أسونسيون"],
            alpha_2_code="PY",
            alpha_3_code="PRY",
            continent="أمريكا الجنوبية",
            name="بابرغوي",
            capital="أسونسيون",
        ),
        Country(
            timezones=["آسيا/قطر"],
            alpha_2_code="QA",
            alpha_3_code="QAT",
            continent="آسيا",
            name="قطر",
            capital="الدوحة",
        ),
        Country(
            timezones=["أوروبا/بوخارست"],
            alpha_2_code="RO",
            alpha_3_code="ROU",
            continent="أوروبا",
            name="رومانيا",
            capital="بوخارست",
        ),
        Country(
            timezones=[
                "أوروبا/كالينينغراد",
                "أوروبا/موسكو",
                "أوروبا/Volgograd",
                "أوروبا/سمارة",
                "آسيا/يكاترينبورغ",
                "آسيا/أومسك",
                "آسيا/نوفوسيبيرسك",
                "آسيا/كراسنوياسك",
                "آسيا/إروتسك",
                "آسيا/ياكوتسك",
                "آسيا/فالديفوستوك",
                "آسيا/ساخالن",
                "آسيا/ماغادان",
                "آسيا/كامشتكا",
                "آسيا/أنادير",
            ],
            alpha_2_code="RU",
            alpha_3_code="RUS",
            continent="أوروبا",
            name="روسيا",
            capital="موسكو",
        ),
        Country(
            timezones=["إفريقيا/كيغالي"],
            alpha_2_code="RW",
            alpha_3_code="RWA",
            continent="إفريقيا",
            name="رواندا",
            capital="كيغالي",
        ),
        Country(
            timezones=["آسيا/الرياض"],
            alpha_2_code="SA",
            alpha_3_code="SAU",
            continent="آسيا",
            name="المملكة العربية السعودية",
            capital="الرياض",
        ),
        Country(
            timezones=["المحيط_الهاديء/غوادالكانال"],
            alpha_2_code="SB",
            alpha_3_code="SLB",
            continent="أوقيانوسيا",
            name="جزر سولمون",
            capital="هونيارا",
        ),
        Country(
            timezones=["الهندي/ماهي"],
            alpha_2_code="SC",
            alpha_3_code="SYC",
            continent="إفريقيا",
            name="سيشل",
            capital="فيكتوريا",
        ),
        Country(
            timezones=["إفريقيا/الخرطوم"],
            alpha_2_code="SD",
            alpha_3_code="SDN",
            continent="إفريقيا",
            name="السودان",
            capital="الخرطوم",
        ),
        Country(
            timezones=["أوروبا/ستوكهولم"],
            alpha_2_code="SE",
            alpha_3_code="SWE",
            continent="أوروبا",
            name="السويد",
            capital="ستوكهولم",
        ),
        Country(
            timezones=["آسيا/سنغافورة"],
            alpha_2_code="SG",
            alpha_3_code="SGP",
            continent="آسيا",
            name="سنغافورة",
            capital="سنغافورة",
        ),
        Country(
            timezones=["أوروبا/ليوبليانا"],
            alpha_2_code="SI",
            alpha_3_code="SVN",
            continent="أوروبا",
            name="سلوفانيا",
            capital="ليوبليانا",
        ),
        Country(
            timezones=["أوروبا/براتيسلافا"],
            alpha_2_code="SK",
            alpha_3_code="SVK",
            continent="أوروبا",
            name="سلوفاكيا",
            capital="براتيسلافا",
        ),
        Country(
            timezones=["إفريقيا/فريتاون"],
            alpha_2_code="SL",
            alpha_3_code="SLE",
            continent="إفريقيا",
            name="سيراليون",
            capital="فريتاون",
        ),
        Country(
            timezones=["أوروبا/سان_مارينو"],
            alpha_2_code="SM",
            alpha_3_code="SMR",
            continent="أوروبا",
            name="جمهورية سان مارينو",
            capital="سان مارينو",
        ),
        Country(
            timezones=["إفريقيا/داكار"],
            alpha_2_code="SN",
            alpha_3_code="SEN",
            continent="إفريقيا",
            name="السنغال",
            capital="داكار",
        ),
        Country(
            timezones=["إفريقيا/مقديشو"],
            alpha_2_code="SO",
            alpha_3_code="SOM",
            continent="إفريقيا",
            name="الصومال",
            capital="مقديشو",
        ),
        Country(
            timezones=["أمريكا/باراماريبو"],
            alpha_2_code="SR",
            alpha_3_code="SUR",
            continent="أمريكا الجنوبية",
            name="Suriname",
            capital="باراماريبو",
        ),
        Country(
            timezones=["إفريقيا/ساو_تومي"],
            alpha_2_code="ST",
            alpha_3_code="STP",
            continent="إفريقيا",
            name=" ساو تومي وبرينسيب",
            capital="ساو تومي",
        ),
        Country(
            timezones=["آسيا/دممشق"],
            alpha_2_code="SY",
            alpha_3_code="SYR",
            continent="آسيا",
            name="سوريا",
            capital="دمشق",
        ),
        Country(
            timezones=["إفريقيا/لومي"],
            alpha_2_code="TG",
            alpha_3_code="TGO",
            continent="إفريقيا",
            name="توغو",
            capital="لومي",
        ),
        Country(
            timezones=["آسيا/بانغوك"],
            alpha_2_code="TH",
            alpha_3_code="THA",
            continent="آسيا",
            name="تايلند",
            capital="بناغوك",
        ),
        Country(
            timezones=["آسيا/دوشنبه"],
            alpha_2_code="TJ",
            alpha_3_code="TJK",
            continent="آسيا",
            name="طاجكيستان",
            capital="دوشنبه",
        ),
        Country(
            timezones=["آسيا/عشق_آباد"],
            alpha_2_code="TM",
            alpha_3_code="TKM",
            continent="آسيا",
            name="تركمانستان",
            capital="عشق آباد",
        ),
        Country(
            timezones=["إفريقيا/تونس"],
            alpha_2_code="TN",
            alpha_3_code="TUN",
            continent="إفريقيا",
            name="تونس",
            capital="تونس",
        ),
        Country(
            timezones=["المحيط_الهاديء/تونغاتابو"],
            alpha_2_code="TO",
            alpha_3_code="TON",
            continent="أوقيانوسيا",
            name="تونغا",
            capital="نوكو ألوفا",
        ),
        Country(
            timezones=["أوروبا/إسطنبول"],
            alpha_2_code="TR",
            alpha_3_code="TUR",
            continent="آسيا",
            name="تركيا",
            capital="أنقرة",
        ),
        Country(
            timezones=["أمريكا/بورت_أوف_سبين"],
            alpha_2_code="TT",
            alpha_3_code="TTO",
            continent="أمريكا الشمالية",
            name="ترينيداد وتوباغو",
            capital="بورت أوف سبين",
        ),
        Country(
            timezones=["المحيط_الهاديء/فونافوتي"],
            alpha_2_code="TV",
            alpha_3_code="TUV",
            continent="أوقيانوسيا",
            name="توفالو",
            capital="فونافوتي",
        ),
        Country(
            timezones=["إفريقيا/دار_السلام"],
            alpha_2_code="TZ",
            alpha_3_code="TZA",
            continent="إفريقيا",
            name="تانزانيا",
            capital="دودوما",
        ),
        Country(
            timezones=[
                "أوروبا/كييف",
                "أوروبا/أوجهورود",
                "أوروبا/زاباروجيا",
                "أوروبا/سيمفروبول",
            ],
            alpha_2_code="UA",
            alpha_3_code="UKR",
            continent="أوروبا",
            name="أوكرانيا",
            capital="كييف",
        ),
        Country(
            timezones=["إفريقيا/كامبالا"],
            alpha_2_code="UG",
            alpha_3_code="UGA",
            continent="إفريقيا",
            name="أوغندا",
            capital="كامبالا",
        ),
        Country(
            timezones=[
                "أمريكا/نيويورك",
                "أمريكا/ديترويت",
                "أمريكا/كنتاكي/لويسفيل",
                "أمريكا/كنتاكي/مونتيسللو",
                "أمريكا/إنديانا/إنديانابولس",
                "أمريكا/إنديانا/مارنغو",
                "أمريكا/إنديانا/نوكس",
                "أمريكا/إنديانا/فيفاي",
                "أمريكا/شيكاغو",
                "أمريكا/إنديانا/فانسان",
                "أمريكا/إنديانا/بيترزبيرغ",
                "أمريكا/مينومني",
                "أمريكا/نورث_داكوتا/سينتر",
                "أمريكا/نورث_داكوتا/نيو_سالم",
                "أمريكا/دنفر",
                "أمريكا/بويسي",
                "أمريكا/شيبروك",
                "أمريكا/فينيكس",
                "أمريكا/لوس_أنجيلوس",
                "أمريكا/أنكوريج",
                "أمريكا/جونو",
                "أمريكا/ياكوتات",
                "أمريكا/نوم",
                "أمريكا/أداك",
                "المحيط_الهاديء/هونولولو",
            ],
            alpha_2_code="US",
            alpha_3_code="USA",
            continent="أمريكا الشمالية",
            name="الولايات المتحدة الأمريكية",
            capital="واشنطن",
        ),
        Country(
            timezones=["أمريكا/مونتفيدو"],
            alpha_2_code="UY",
            alpha_3_code="URY",
            continent="أمريكا الجنوبية",
            name="أوروغواي",
            capital="مونتفيدو",
        ),
        Country(
            timezones=["آسيا/سمرقند", "آسيا/طشقند"],
            alpha_2_code="UZ",
            alpha_3_code="UZB",
            continent="آسيا",
            name="أوزبكستان",
            capital="طشقند",
        ),
        Country(
            timezones=["أوروبا/الفاتيكان"],
            alpha_2_code="VA",
            alpha_3_code="VAT",
            continent="أوروبا",
            name="الفاتيكان",
            capital="الفاتيكان",
        ),
        Country(
            timezones=["أمريكا/كاركاس"],
            alpha_2_code="VE",
            alpha_3_code="VEN",
            continent="أمريكا الجنوبية",
            name="فنزويلا",
            capital="كاركاس",
        ),
        Country(
            timezones=["آسيا/سايغون"],
            alpha_2_code="VN",
            alpha_3_code="VNM",
            continent="آسيا",
            name="فيتنام",
            capital="هانوي",
        ),
        Country(
            timezones=["المحيط_الهاديء/أيفاتي"],
            alpha_2_code="VU",
            alpha_3_code="VUT",
            continent="أوقيانوسيا",
            name="فانواتو",
            capital="بورت فيلا",
        ),
        Country(
            timezones=["آسيا/عدن"],
            alpha_2_code="YE",
            alpha_3_code="YEM",
            continent="آسيا",
            name="اليمن",
            capital="صنعاء",
        ),
        Country(
            timezones=["إفريقيا/لوساكا"],
            alpha_2_code="ZM",
            alpha_3_code="ZMB",
            continent="إفريقيا",
            name="زامبيا",
            capital="لوساكا",
        ),
        Country(
            timezones=["إفريقيا/هراري"],
            alpha_2_code="ZW",
            alpha_3_code="ZWE",
            continent="إفريقيا",
            name="زيمبابوي",
            capital="هراري",
        ),
        Country(
            timezones=["إفريقيا/الجزائر"],
            alpha_2_code="DZ",
            alpha_3_code="DZA",
            continent="إفريقيا",
            name="الجزائر",
            capital="الجزائر",
        ),
        Country(
            timezones=["أوروبا/سراييفو"],
            alpha_2_code="BA",
            alpha_3_code="BIH",
            continent="أوروبا",
            name="البوسنة والهرسك",
            capital="سراييفو",
        ),
        Country(
            timezones=["آسيا/بنوم_بنه"],
            alpha_2_code="KH",
            alpha_3_code="KHM",
            continent="آسيا",
            name="كمبوديا",
            capital="بنوم بنه",
        ),
        Country(
            timezones=["إفريقيا/بانغي"],
            alpha_2_code="CF",
            alpha_3_code="CAF",
            continent="إفريقيا",
            name="جمهورية أفريقيا الوسطى",
            capital="بانغي",
        ),
        Country(
            timezones=["إفريقيا/نجامينا"],
            alpha_2_code="TD",
            alpha_3_code="TCD",
            continent="إفريقيا",
            name="تشاد",
            capital="نجامينا",
        ),
        Country(
            timezones=["الهندي/كومورو"],
            alpha_2_code="KM",
            alpha_3_code="COM",
            continent="إفريقيا",
            name="جزر القمر",
            capital="موروني",
        ),
        Country(
            timezones=["أوروبا/زغرب"],
            alpha_2_code="HR",
            alpha_3_code="HRV",
            continent="أوروبا",
            name="كرواتيا",
            capital="زغرب",
        ),
        Country(
            timezones=["آسيا/ديلي"],
            alpha_2_code="TL",
            alpha_3_code="TLS",
            continent="آسيا",
            name="تيمور الشرقية",
            capital="ديلي",
        ),
        Country(
            timezones=["أمريكا/السلفادور"],
            alpha_2_code="SV",
            alpha_3_code="SLV",
            continent="أمريكا الشمالية",
            name="السلفادور",
            capital="سان سلفادور",
        ),
        Country(
            timezones=["إفريقيا/مالابو"],
            alpha_2_code="GQ",
            alpha_3_code="GNQ",
            continent="إفريقيا",
            name="غينيا الاستوائية",
            capital="مالابو",
        ),
        Country(
            timezones=["أمريكا/غرينادا"],
            alpha_2_code="GD",
            alpha_3_code="GRD",
            continent="أمريكا الشمالية",
            name="غرينادا",
            capital="سانت جورجز",
        ),
        Country(
            timezones=[
                "آسيا/ألماتي",
                "آسيا/كيزيلوردا",
                "آسيا/أقتوبي",
                "آسيا/أقتاو",
                "آسيا/أورال",
            ],
            alpha_2_code="KZ",
            alpha_3_code="KAZ",
            continent="آسيا",
            name="كازاخستان",
            capital="أستانة",
        ),
        Country(
            timezones=["آسيا/فيينتيان"],
            alpha_2_code="LA",
            alpha_3_code="LAO",
            continent="آسيا",
            name="لاوس",
            capital="فيينتيان",
        ),
        Country(
            timezones=[
                "المحيط_الهاديء/تشوك",
                "المحيط_الهاديء/بونابي",
                "المحيط_الهاديء/كورساي",
            ],
            alpha_2_code="FM",
            alpha_3_code="FSM",
            continent="أوقيانوسيا",
            name="ولايات ميكرونيسيا المتحدة",
            capital="باليكير",
        ),
        Country(
            timezones=["أوروبا/كيشيناو"],
            alpha_2_code="MD",
            alpha_3_code="MDA",
            continent="أوروبا",
            name="مولدافيا",
            capital="كيشيناو",
        ),
        Country(
            timezones=["أوروبا/موناكو"],
            alpha_2_code="MC",
            alpha_3_code="MCO",
            continent="أوروبا",
            name="موناكو",
            capital="موناكو",
        ),
        Country(
            timezones=["أوروبا/بودغوريتسا"],
            alpha_2_code="ME",
            alpha_3_code="MNE",
            continent="أوروبا",
            name="الجبل الأسود",
            capital="بودغوريتسا",
        ),
        Country(
            timezones=["إفريقيا/الدار_البيضاء"],
            alpha_2_code="MA",
            alpha_3_code="MAR",
            continent="إفريقيا",
            name="المغرب",
            capital="الرباط",
        ),
        Country(
            timezones=["أمريكا/سانت_كيتس"],
            alpha_2_code="KN",
            alpha_3_code="KNA",
            continent="أمريكا الشمالية",
            name="سانت كيتس ونيفيس",
            capital="باستير",
        ),
        Country(
            timezones=["أمريكا/سانت_لوسيا"],
            alpha_2_code="LC",
            alpha_3_code="LCA",
            continent="أمريكا الشمالية",
            name="سانت لوسيا",
            capital="كاستريس",
        ),
        Country(
            timezones=["أمريكا/سينت_فينسينت"],
            alpha_2_code="VC",
            alpha_3_code="VCT",
            continent="أمريكا الشمالية",
            name="سانت فينسنت والغرينادين",
            capital="كينغستاون",
        ),
        Country(
            timezones=["المحيط_الهاديء/أبيا"],
            alpha_2_code="WS",
            alpha_3_code="WSM",
            continent="أوقيانوسيا",
            name="ساموا",
            capital="أبيا",
        ),
        Country(
            timezones=["أوروبا/بلغراد"],
            alpha_2_code="RS",
            alpha_3_code="SRB",
            continent="أوروبا",
            name="صربيا",
            capital="بلغراد",
        ),
        Country(
            timezones=["إفريقيا/جوهانسبرغ"],
            alpha_2_code="ZA",
            alpha_3_code="ZAF",
            continent="إفريقيا",
            name="جنوب إفريقيا",
            capital="بريتوريا",
        ),
        Country(
            timezones=["أوروبا/مدريد", "إفريقيا/سبتة", "الأطلنطي/الكناري"],
            alpha_2_code="ES",
            alpha_3_code="ESP",
            continent="أوروبا",
            name="إسبانيا",
            capital="مدريد",
        ),
        Country(
            timezones=["آسيا/كولمبو"],
            alpha_2_code="LK",
            alpha_3_code="LKA",
            continent="آسيا",
            name="سريلانكا",
            capital="سري جاياواردنابورا كوتي",
        ),
        Country(
            timezones=["إفريقيا/مبابان"],
            alpha_2_code="SZ",
            alpha_3_code="SWZ",
            continent="إفريقيا",
            name="سوازيلاند",
            capital="مبابان",
        ),
        Country(
            timezones=["أوروبا/زيورخ"],
            alpha_2_code="CH",
            alpha_3_code="CHE",
            continent="أوروبا",
            name="سويسرا",
            capital="برن",
        ),
        Country(
            timezones=["آسيا/دبي"],
            alpha_2_code="AE",
            alpha_3_code="ARE",
            continent="آسيا",
            name="الإمارات العربية المتحدة",
            capital="أبو ظبي",
        ),
        Country(
            timezones=["أوروبا/لندن"],
            alpha_2_code="GB",
            alpha_3_code="GBR",
            continent="أوروبا",
            name="المملكة المتحدة",
            capital="لندن",
        ),
    ]

    AM_PM = {
        "AM": "ص",
        "PM": "م",
    }

    def month_name(self) -> str:
        month = self.date("%m")
        return self.MONTH_NAMES[month]

    def am_pm(self) -> str:
        date = self.date("%p")
        return self.AM_PM[date]

    def day_of_week(self) -> str:
        day = self.date("%w")
        return self.DAY_NAMES[day]



from .. import Provider as JobProvider


class Provider(JobProvider):
    """Translated from Super class"""

    jobs = (
        "Administrátor, umění",
        "Administrátor, státní služba",
        "Advokát",
        "Advokát pro ochranné známky",
        "Akademický knihovník",
        "Akupunkturista",
        "Analytický chemik",
        "Analytik finančního rizika",
        "Angličtina jako lektorka cizího jazyka",
        "Angličtina jako učitel druhého jazyka",
        "Animátor",
        "Arborista",
        "Archeológ",
        "Architekt",
        "Architektonický technológ",
        "Archivář",
        "Arteterapeut",
        "Asistent politika",
        "Astronóm",
        "Audiologický vědec",
        "Automobilový inženýr",
        "Autorizovaný likvidátor ztrát",
        "Autorizovaný účetní",
        "Autorizovaný účetní v oblasti veřejných financí",
        "Bankéř",
        "Báňský inženýr",
        "Barista",
        "Biochemik, klinický",
        "Biomedicínsky inženýr",
        "Biomedicínsky vědec",
        "Bylinkář",
        "Bytový manažér / referent",
        "Charitatívní úředník",
        "Chemický inženýr",
        "Chemik, analytický",
        "Chiropraktik",
        "Chirurg",
        "Copywriter, reklama",
        "Cytogenetik",
        "Daňový poradce",
        "Dětská sestra",
        "Dětský psychoterapeut",
        "Diagnostický rádiograf",
        "Dietológ",
        "Dyzajnér, foukané sklo / vitráž",
        "Dyzajnér, grafik",
        "Dyzajnér, interiér / protor",
        "Dyzajnér, keramika / hrčířství",
        "Dyzajnér, multimédiá",
        "Dyzajnér, móda / oblečení",
        "Dyzajnér, nábytek",
        "Dyzajnér, průmyslový / produkt",
        "Dyzajnér, televíize / film",
        "Dyzajnér, textil",
        "Dyzajnér, výstava / výstava",
        "Dyzajnér, šperky",
        "Docent",
        "Dodávateľ",
        "Dospělý poradentský pracovník",
        "Dozorce",
        "Dramatický terapeut",
        "Důstojník obchodního námořníctví",
        "Důstojník pro ochranu přírody",
        "Důstojník pro výcvik a vzdělávní ozbrojených síl",
        "Editor funkcie časopisu",
        "Ekológ",
        "Ekonom",
        "Elektroinženýr",
        "Embryológ, klinický",
        "Energetický inženýr",
        "Energetický manažér",
        "Environmentálny manažér",
        "Ergonóm",
        "Barevný technológ",
        "Farmaceut Spoločenstva",
        "Farmakológ",
        "Filmový / video editor",
        "Finanční kontrolor",
        "Finanční manažér",
        "Finanční obchodník",
        "Finanční plánovač",
        "Finanční poradce",
        "Finanční ředitel",
        "Firemní sekretářka",
        "Fotograf",
        "Fytoterapeut",
        "Fyzik zdraví",
        "Fyzik, lékař",
        "Fyziologický vědec",
        "Fyziológ cvičení",
        "Fyzioterapeut",
        "Foukač akla / dyzajnér",
        "Genetik, molekulárny",
        "Geochemik",
        "Geodet minerálu",
        "Geodet pojištění rizika",
        "Geofyzik / terénní seismológ",
        "Geológ, strojař",
        "Geológ",
        "Geovedec",
        "Grafický dyzajnér",
        "Grafik",
        "Hasič",
        "Hematológ",
        "Herec",
        "Herpetológ",
        "Hlavní marketingový ředitel",
        "Homeopat",
        "Hotelový manažér",
        "Hudebník",
        "Hudební lektor",
        "Hudební terapeut",
        "Hutník",
        "Hydrogeológ",
        "Hydrografický geodet",
        "Hydrológ",
        "Hygienik práce",
        "IT konzultant",
        "Ilustrátor",
        "Imunológ",
        "Informační úředník",
        "Investiční analytik",
        "Investiční bankář, funkční",
        "Investiční bankář, podnikový",
        "Inspektor / hodnotitel reklamací",
        "Inspektor historických budov / referent památkové ochrany",
        "Inspektor plánovaní a rozvoje",
        "Inspektor zdraví a bezpečnosti",
        "Inženýr budov",
        "Inženýr elektroniky",
        "Inženyr kontroly a přístrojového vybavení",
        "Inženýr zemědělství",
        "Inženýr pro automobilový průmysl",
        "Inženýr výrobních systémovů",
        "Inženýr, bankovnictví",
        "Inženýr, biomedicíny",
        "Inženýr, chemický",
        "Inženýr, elektronika",
        "Inženýr, elektrotechnik",
        "Inženýr, energie",
        "Inženýr, komunikace",
        "Inženýr, letecký",
        "Inženýr, materiály",
        "Inženýr, pozemky",
        "Inženýr, zemědělství",
        "Inženýr, řízení a přístrojové vybavení",
        "Inženýr, ropa",
        "Inženýr, statik",
        "Inženýr, stavební služby",
        "Inženýr, stavební (smluvní)",
        "Inženýr, stavební inženier (poradenství)",
        "Inženýr, technický prodej",
        "Inženýr, voda",
        "Inženýr, vysílání (provoz)",
        "Inženýr, výroba",
        "Inženýr, výroba",
        "Inženýr, výrobní systémy",
        "Inženýr, vrtaní",
        "Inženýr, web",
        "Inženýr, údržba",
        "Inženýr, údržba (IT)",
        "Inženýrský geológ",
        "Kameraman",
        "Kariérní informační úředník",
        "Kariérní poradce",
        "Kariérní poradce pro vysokoškolské vzdělání",
        "Kartograf",
        "Klinický biochemik",
        "Klinický cytogenetik",
        "Klinický embryológ",
        "Klinický molekulárny genetik",
        "Klinický psychológ",
        "Klinický vědec, histokompatibilita a imunogenetika",
        "Knihovník",
        "Knihovník, veřejný",
        "Kníhkupec",
        "Komerční / rezidenční geodet",
        "Komerční záhradník",
        "Komunikační inženýr",
        "Komunitní umělecký pracovník",
        "Jednatel spoločnosti",
        "Kontrolór",
        "Konzervátor / restauratér nábytku",
        "Konzervátor muzea / galérie",
        "Konzervátor, muzeum / galéria",
        "Konzervátor, nábytku",
        "Konzultant pro důchody",
        "Konzultace se stavebním inženýrem",
        "Koordinátor dobrovolnictví",
        "Kupující, maloobchod",
        "Kurátor",
        "Kurátor muzea / galérie",
        "Lektor dalšího vzdělávání",
        "Lektor, vysokoškolské vzdělání",
        "Lektor, další vzdělání",
        "Lékař všeobecného lekařství",
        "Lékař, nemocnice",
        "Lékař, všeobecná praxe",
        "Lékárnik, komunita",
        "Lékárnik, nemocnice",
        "Lékářsky fyzik",
        "Lékářsky ilustrátor",
        "Lékářsky obchodní zástupca",
        "Lékářsky sekretář",
        "Lékářsky technický pracovník",
        "Letecký dispečer",
        "Letecký inženýr",
        "Letecký sprostředkovateľ",
        "Lexikograf",
        "Licencovaný dopravce",
        "Lobista",
        "Logistika / podpora / administratívní důstojník ozbrojených síl",
        "Manažér call centra",
        "Manažér cestovní kanceláře",
        "Manažér divadelní scény",
        "Manažér farmy",
        "Manažér fitnescentra",
        "Manažér informačných systému",
        "Manažér komerční umělecké galérie",
        "Manažér logistiky a distribuce",
        "Manažér stravování",
        "Manažér umělecké galérie",
        "Manažér zařízení",
        "Manažér zábavného parku",
        "Manžérsky konzultant",
        "Marketingový manažér",
        "Materiálový inženýr",
        "Mediální plánovač",
        "Meteorológ",
        "Mikrobiológ",
        "Moderátor, vysílání",
        "Mořský vědec",
        "Multimediální programy",
        "Módní návrhář",
        "Nemocniční lékař",
        "Nemocniční lekárniík",
        "Neurochirurg",
        "Novinář novín",
        "Novinář časopisu",
        "Novinář, noviny",
        "Novinář, vysílání",
        "Novinář, časopis",
        "Nákupčí médií",
        "Nákupčí, průmyslu",
        "Námořní architekt",
        "Návrhář interiérů a prostor",
        "Návrhář nábytku",
        "Návrhář výstavy",
        "Návrhář šperkov",
        "Návrhářka keramiky",
        "Obchodník s akciemi",
        "Obchodník s dluhopisy",
        "Obchodník s futures",
        "Oceánograf",
        "Ochranář, historické budovy",
        "Odborník na životní prostředí",
        "Oděvní / textilní technológ",
        "Onkológ",
        "Operatívní výzkumník",
        "Operační důstojních diplomatických služeb",
        "Operačn důstojník ozbrojených síl",
        "Optik, výdej",
        "Optometrista",
        "Ortoptista",
        "Osobní asistent",
        "Osteopat",
        "Oční lékař",
        "Palubní průvodce",
        "Patent attorney",
        "Patológ",
        "Pedagogický psychológ",
        "Pedikér",
        "Personalista",
        "Pilot letecké společnosti",
        "Plánovač dopravy",
        "Plánovač reklamního účtu",
        "Plánovač tisku",
        "Podnikový investiční bankéř",
        "Podnikový pokladník",
        "Pojistný matematik",
        "Pojišťovací makléř",
        "Pojišťovák",
        "Police officer",
        "Poradce pro zdraví a bezpečnosť",
        "Poradce pro životní prostředí",
        "Poradenský pracovník",
        "Poradenský psychológ",
        "Potravinářsky technológ",
        "Zemědělský konzultant",
        "Pracovník medzinárodní pomoci / rozvoje",
        "Pracovník pomoci",
        "Pracovník rozvoje komunity",
        "Pracovník s mládeží",
        "Pracovní psychológ",
        "Pracovní terapeut",
        "Predejce",
        "Překladateľ",
        "Prevozovatel televizní kamery",
        "Provozní geológ",
        "Provozní investiční bankéř",
        "Provozní ředitel",
        "Průmyslový / produktový dizajnér",
        "Průmyslový kupující",
        "Průzkumník trhu",
        "Probační úředník",
        "Producent, rádio",
        "Producent, televize / film / video",
        "Production assistant, radio",
        "Production assistant, televize",
        "Production designer, theatre/television/film",
        "Production engineer",
        "Production manager",
        "Produktový dizajnér",
        "Produktový manažér",
        "Professor Emeritus",
        "Programátor, applikací",
        "Programátor, multimedia",
        "Programátor, systems",
        "Korektor",
        "Právnik",
        "Právní tajemník",
        "Psychiatrická sestra",
        "Psychitr",
        "Psycholog, klinický",
        "Psycholog, poradenství",
        "Psycholog, vzdělání",
        "Psycholog, forézní",
        "Psycholog, pracovní",
        "Psycholog, vězeňské a probační služby",
        "Psycholog, sport a cvičení",
        "Psychoterapeut tanečního pohybu",
        "Psychoterapeut",
        "Porodní asistentka",
        "Manažér kvality",
        "Poradce",
        "Realitní makléř",
        "Redaktor, uvedení do provozu",
        "Redakční asistent",
        "Referent cestovního ruchu",
        "Referent environmentální výchovy",
        "Referent geografických informačných systému",
        "Referent komunitního vzdělávání",
        "Referent múzejního vzdělávání",
        "Referent obchodních norem",
        "Referent ochrany přírody",
        "Referent odborné přípravy a rozvoje",
        "Referent odborového výzkumu",
        "Referent zemědělských pokusu",
        "Referent pro nouzové plánování / řízení",
        "Referent pro výstavy v muzeich / galeriich",
        "Referent rozvoje umění",
        "Referent technické podpory IT",
        "Referent výstavy, muzeum / galérii",
        "Referent lidských zdrojů",
        "Školní referent, komunita",
        "Školení referent, muzeum",
        "Regulátor ztrát, objednaný",
        "Reklamní textař",
        "Reklamní umělecký ředitel",
        "Ředitel pro stretegii",
        "Ropný inženýr",
        "Rozvojový pracovník, komunita",
        "Rozvojový pracovník, mezinárodní pomoc",
        "Sanitka",
        "Sestra pro dospělé",
        "Sestra pro duševní zdraví",
        "Sestra s poruchami učení",
        "Sestra, dětská",
        "Sestra, dospělý",
        "Sestra, porucha učení",
        "Sietový inženýr",
        "Spisovateľ",
        "Spolupracovník pro klinický výzkum",
        "Spracovatel geofyzikálnych údajů",
        "Spravodajský analytik",
        "Správce",
        "Správce databázy",
        "Správce dědictví",
        "Správce duchodového systému",
        "Správce lesů",
        "Správce nemovitostí / pozemkový agent",
        "Správce pojisných účtu",
        "Správce polohy",
        "Správce zpracovaní údajů",
        "Správce umění",
        "Správce zákazníckého centra",
        "Správce školní",
        "Správce státní služby",
        "Správce, charitatívní / dobrovolnické organizáce",
        "Správce, místní samospráva",
        "Správce, vzdělávání",
        "Správce, sport",
        "Stavební geodet",
        "Stavební inženýr, poradenství",
        "Stavební inženýr, uzavírání smluv",
        "Střihač, film / video",
        "Strojní inženýr",
        "Strážce",
        "Osvětlovací technik, vysílání / film / video",
        "Soudce psychológ",
        "Soudní vědec",
        "Soukromý učitel hudby",
        "Tanečnice",
        "Technický důstojník ozbrojených síl",
        "Technik údržby",
        "Technológ pro zvířata",
        "Technológ vaření piva",
        "Terapeut, drama",
        "Terapeut, hudba",
        "Terapeut, záhradnícký",
        "Terapeut, sport",
        "Terénní seismológ",
        "Tlumočník",
        "Toxikológ",
        "Umělec",
        "Učicí se mentor",
        "Učitel, angličtina jako cizí jazyk",
        "Učitel, hudba",
        "Učitel, vzdělání dospělých",
        "Učitel, základní škola",
        "Učitel na základní škole",
        "Vědec pro kvalitu vody",
        "Vědec vývoj produktů / procesů",
        "Vědecký pracovník lékařské laboratoře",
        "Vedoucí kanceláře",
        "Vedoucí konferenčního centra",
        "Vedoucí osobní dopravy",
        "Vedoucí outdoorových aktivít / vzdělávání",
        "Vedoucí reklamního účtu",
        "Vedoucí restaurace rychlého občerstvení",
        "Vedoucí rybí farmy",
        "Vedoucí skladu",
        "Vedoucí střediska volného času",
        "Vedoucí turistického informačného centra",
        "Vedoucí ubytování",
        "Vedoucí zdravotní služby",
        "Vedoucí úseku",
        "Veterinární chirurg",
        "Video editor",
        "Vizuální obchodník",
        "Vládní úředník pro sociální výzkum",
        "Vodní inženýr",
        "Vrtný inženýr",
        "Zprostředkovatel pojistných událostí",
        "Vysokoškolský lektor",
        "Výkonný ředitel",
        "Výkonný technický ředitel",
        "Výrobní inženýr",
        "Výtvarný umělec",
        "Vývojář aplikací",
        "Vývojář her",
        "Vývojář počítačových her",
        "Vývojář systémů",
        "Výživový poradca pro zvířata",
        "Výživový terapeut",
        "Web designer",
        "Zaměstnanec imigračního úřadu",
        "Zdravotní sestra, duševní zdraví",
        "Zeměměřič / geomatik",
        "Zmluvní stavební inženýr",
        "Zubař",
        "Záchranář",
        "Záhradnícký konzultant",
        "Záhradnícký terapeut",
        "Záhradník, komerční",
        "Záhradní architekt",
        "Úředník místní samosprávy",
        "Úřadník pro rybolov",
        "Účetní, autorizované veřejné finance",
        "Účetní, autorizovaný",
        "Účetní, autorizovaný / certifikovaný",
        "Účetní technik",
        "Specialista na multimédiá",
        "Specialista na podporu zdraví",
        "Dopravce",
        "Šlechtitel rostlin / genetik",
    )

    def job(self) -> str:
        return self.random_element(self.jobs)



from .. import Provider as InternetProvider


class Provider(InternetProvider):
    safe_email_tlds = ("com", "net", "br", "br")
    free_email_domains = (
        "gmail.com",
        "hotmail.com",
        "yahoo.com.br",
        "uol.com.br",
        "bol.com.br",
        "terra.com.br",
        "outlook.com.br",
        "live.com",
        "icloud.com",
    )
    tlds = (
        "com",
        "com",
        "com",
        "net",
        "org",
        "br",
        "br",
        "br",
        "edu.br",
        "gov.br",
        "gov.br",
        "com.br",
        "com.br",
        "com.br",
    )
    replacements = (
        ("à", "a"),
        ("á", "a"),
        ("â", "a"),
        ("ã", "a"),
        ("ç", "c"),
        ("é", "e"),
        ("ê", "e"),
        ("í", "i"),
        ("ô", "o"),
        ("ö", "o"),
        ("õ", "o"),
        ("ó", "o"),
        ("ú", "u"),
    )



from .. import Provider as InternetProvider


class Provider(InternetProvider):
    free_email_domains = (
        "gmail.com",
        "hotmail.com",
        "yahoo.com",
        # Hungarian free email providers (Magyar e-mail szolgáltatók):
        # https://madweb.hu/a-7-legjobb-ingyenesen-hasznalhato-e-mail-szolgaltatas/
        "freemail.hu",
        "citromail.hu",
        "indamail.hu",
        "mailbox.hu",
    )

    tlds = (
        "hu",
        "com",
        "com.hu",
        "info",
        "org",
        "net",
        "biz",
    )

    replacements = (
        ("ö", "o"),
        ("ü", "u"),
        ("á", "a"),
        ("é", "e"),
        ("í", "i"),
        ("ó", "o"),
        ("ő", "o"),
        ("ú", "u"),
        ("ű", "u"),
    )



from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    formats = (
        "{{last_name}} {{company_suffix}}",
        "{{last_name}} {{last_name}} {{company_suffix}}",
        "{{large_company}}",
    )
    # Source: https://www.capital.com.tr/listeler/capital-500
    large_companies = (
        "Tüpraş",
        "Türk Hava Yolları",
        "Petrol Ofisi",
        "Opet Petrolcülük",
        "Ford Otosan",
        "BİM Birleşik Mağazalar",
        "Arçelik",
        "Shell&Turcas Petrol",
        "Ereğli Demir Çelik",
        "Türk Telekom",
        "Toyota Otomotiv",
        "Tofaş Oto Fabrika",
        "Turkcell",
        "Oyak Renault",
        "Migros",
        "RC Rönesans İnşaat",
        "Doğuş Otomotiv",
        "Anadolu Efes Biracılık",
        "LC Waikiki Mağazacılık",
        "Enerjisa Enerji",
        "Vodafone",
        "Vestel Elektronik",
        "Mercedes-Benz Türk",
        "Şişecam",
        "İÇDAŞ Çelik Enerji",
        "JTI Tütün Ürünleri Pazarlama",
        "Selçuk Ecza",
        "İskenderun Demir Çelik",
        "Enka İnşaat",
        "Kibar Dış Ticaret",
        "Hyundai Assan Otomotiv",
        "Şok Marketler",
        "İstanbul Altın Rafinerisi",
        "Coca-Cola İçecek",
        "Aygaz",
        "İçtaş İnşaat",
        "BSH Ev Aletleri",
        "Petkim",
        "Otokoç",
        "THY Opet",
        "İGDAŞ İstanbul Gaz Dağıtım",
        "Limak İnşaat",
        "Hayat Kimya",
        "Limak Yatırım",
        "Mapa İnşaat",
        "Aytemiz Akaryakıt Dağıtım",
        "Aselsan",
        "Pegasus Hava Taşımacılığı",
        "TUSAŞ-Türk Havacılık ve Uzay",
        "GAP İnşaat",
        "Tosçelik Profil ve Saç",
        "Unilever",
        "Tekfen İnşaat",
        "Ülker Bisküvi",
        "Çalık Enerji",
        "Indeks Bilgisayar",
        "Güneş Ekspres Havacılık",
        "TAV Havalimanları",
        "CarrefourSA",
        "Borçelik Çelik Sanayi",
        "Sarkuysan",
        "Trakya Cam",
        "Türk Traktör",
        "Mey İçki",
        "Kardemir",
        "İpragaz",
        "Zorlu Enerji",
        "Vestel Beyaz Eşya",
        "Aksa Enerji Üretim",
        "TGS Dış Ticaret",
        "TP Petrol Dağıtım",
        "Gübre Fabrikaları",
        "Gediz Elektrik Perakende Satış",
        "BASF Türkiye",
        "Er-Bakır Elektrolitik Bakır",
        "Teknosa İç ve Dış Ticaret",
        "Kroman Çelik",
        "Eren Enerji",
        "Tiryaki Agro Gıda",
        "Acıbadem Sağlık Hizmetleri",
        "Yücel Boru ve Profil",
        "Baştuğ Metalurji",
        "Eti Gıda",
        "Philsa Philip Morris Sabancı Sigara",
        "Netlog Lojistik Hizmetleri",
        "İzmir Demir Çelik",
        "Assan Alüminyum",
        "Tepe İnşaat",
        "Honda Türkiye",
        "Koton",
        "Bizim Toptan Satış Mağazaları",
        "Aksa Akrilik",
        "Aksa Doğalgaz",
        "Borusan Otomotiv",
        "Kastamonu Entegre",
        "Sepaş Enerji Sakarya Elektrik",
        "TAV Tepe Akfen",
        "Konya Şeker Fabrikası",
    )
    company_suffixes = (
        "A.Ş.",
        "Ltd.",
        "Tic.",
        "San.",
        "Şti.",
    )

    def large_company(self) -> str:
        """
        :example: 'Peak Games'
        """
        return self.random_element(self.large_companies)



from collections import OrderedDict

from .. import Provider as CompanyProvider


class Provider(CompanyProvider):
    """
    Provider for company names for es_ES locale

    Company naming scheme and probabilities are inspired by and/or based on existing companies in Spain.

    Sources:
    - https://en.wikipedia.org/wiki/List_of_legal_entity_types_by_country
    - https://ranking-empresas.eleconomista.es/ranking_empresas_nacional.html
    """

    formats = (
        "{{company_prefix}} {{last_name}} {{company_suffix}}",
        "{{company_type}} {{random_company_acronym}} {{company_suffix}}",
        "{{company_type}} {{last_name}} {{company_suffix}}",
        "{{company_type}} {{random_company_adjective}} {{company_suffix}}",
        "{{company_type}} {{last_name}} {{random_name_complements}} {{company_suffix}}",
        "{{last_name}} {{random_name_complements}} {{company_suffix}}",
        "{{last_name}} y {{last_name}} {{company_suffix}}",
        "{{first_name}} {{last_name}} {{last_name}} {{company_suffix}}",
    )

    company_suffixes = OrderedDict(
        [
            ("S.A.", 0.19860906),
            ("S.A.D", 0.01020618),
            ("S.A.T.", 0.02307813),
            ("S.A.U", 0.01506562),
            ("S.C.P", 0.04465719),
            ("S.Com.", 0.15636432),
            ("S.Coop.", 0.17394866),
            ("S.L.", 0.18325857),
            ("S.L.L.", 0.05800693),
            ("S.L.N.E", 0.11496705),
            ("S.L.U.", 0.02183831),
        ]
    )

    company_prefixes = (
        "Familia",
        "Grupo",
        "Hermanos",
        "Hnos",
    )

    company_types = (
        "Alimentación",
        "Banca Privada",
        "Banco",
        "Comercial",
        "Comercializadora",
        "Compañía",
        "Construcción",
        "Consultoría",
        "Desarrollo",
        "Despacho",
        "Distribuciones",
        "Farmaceútica",
        "Finanzas",
        "Fábrica",
        "Hotel",
        "Industrias",
        "Infraestructuras",
        "Inmobiliaria",
        "Instalaciones",
        "Inversiones",
        "Logística",
        "Manufacturas",
        "Minería",
        "Promociones",
        "Restauración",
        "Servicios",
        "Soluciones",
        "Suministros",
        "Supermercados",
        "Talleres",
        "Tecnologías",
        "Transportes",
    )

    name_complements = (
        "& Asociados",
        "y asociados",
    )

    company_adjectives = (
        "Avanzadas",
        "Castellana",
        "Española",
        "Españolas",
        "Globales",
        "Iberia",
        "Ibérica",
        "Ibéricos",
        "Integrales",
        "Inteligentes",
        "Internacionales",
        "del Levante",
        "del Mediterráneo",
        "del Noroeste",
        "del Norte",
        "del Sur",
    )

    def company_type(self) -> str:
        return self.random_element(self.company_types)

    def company_suffix(self) -> str:
        return self.random_element(self.company_suffixes)

    def random_name_complements(self) -> str:
        return self.random_element(self.name_complements)

    def random_company_adjective(self) -> str:
        return self.random_element(self.company_adjectives)

    def random_company_acronym(self) -> str:
        letters = self.random_letters(self.random_int(2, 4))
        return "".join(letters).upper()

    def company_prefix(self) -> str:
        return self.random_element(self.company_prefixes)



from typing import Dict, Tuple

from faker.typing import SexLiteral

from ... import ElementsType
from .. import Provider as BaseProvider

GENDER_TO_GENERATOR: Dict[SexLiteral, str] = {
    "F": "{{last_name_female}} {{first_name_female}} {{middle_name_female}}",
    "M": "{{last_name_male}} {{first_name_male}} {{middle_name_male}}",
    "X": "{{last_name_male}} {{first_name_male}} {{middle_name_male}}",
}


class Provider(BaseProvider):
    passport_number_formats: ElementsType = (
        "## ## ######",
        "#### ######",
    )

    def passport_owner(self, gender: SexLiteral = "M") -> Tuple[str, str]:
        generator_string = GENDER_TO_GENERATOR[gender]
        last_name, first_name, middle_name = self.generator.parse(generator_string).split()

        first_name_united_with_middle = first_name + " " + middle_name
        return last_name, first_name_united_with_middle



from .. import Provider as AutomotiveProvider

# flake8: noqa: E501


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``ja_JP`` locale.

    Sources (retrieved on 2025-09-15):

    - https://ja.wikipedia.org/wiki/%E6%97%A5%E6%9C%AC%E3%81%AE%E3%83%8A%E3%83%B3%E3%83%90%E3%83%BC%E3%83%97%E3%83%AC%E3%83%BC%E3%83%88%E4%B8%80%E8%A6%A7
    - http://nplate.cloudfree.jp/misc/m50_bango.html
    """

    license_plate_area_names = (
        "品川",
        "足立",
        "練馬",
        "横浜",
        "川崎",
        "名古屋",
        "大阪",
        "神戸",
        "福岡",
        "札幌",
        "尾張小牧",
        "伊勢志摩",
    )

    classification_numbers = (
        "###",
        "##",
    )

    license_plate_kana = (
        "あ",
        "い",
        "う",
        "え",
        "か",
        "き",
        "く",
        "け",
        "こ",
        "さ",
        "す",
        "せ",
        "そ",
        "た",
        "ち",
        "つ",
        "て",
        "と",
        "な",
        "に",
        "ぬ",
        "ね",
        "の",
        "は",
        "ひ",
        "ふ",
        "ほ",
        "ま",
        "み",
        "む",
        "め",
        "も",
        "や",
        "ゆ",
        "よ",
        "ら",
        "り",
        "る",
        "れ",
        "ろ",
        "わ",
        "を",
    )

    serial_number_formats = ("#", "##", "###", "####")

    MIDDLE_DOT = "・"
    DELIMITER = "-"

    license_plate_formats = ("{{area_name}} {{classification_number}} {{kana}} {{serial_number}}",)

    def license_plate(self) -> str:
        """Generate a Japanese license plate."""
        pattern = self.random_element(self.license_plate_formats)
        return self.generator.parse(pattern)

    def area_name(self) -> str:
        return self.random_element(self.license_plate_area_names)

    def classification_number(self) -> str:
        return self.numerify(self.random_element(self.classification_numbers))

    def kana(self) -> str:
        return self.random_element(self.license_plate_kana)

    def serial_number(self) -> str:
        """
        Generate the vehicle’s serial number (the last four digits on a Japanese license plate).
        - For 4 digits: insert a hyphen between the second and third digits (e.g., 12-34).
        - For 1 to 3 digits: pad the left side with middle dots (・) so the total width is four
          characters (e.g., ・123, ・・12, ・・・1). Do not use a hyphen in these cases.
        """

        raw_digits = self.numerify(self.random_element(self.serial_number_formats))
        n = len(raw_digits)

        if n == 4:
            v = f"{raw_digits[:2]}{self.DELIMITER}{raw_digits[2:]}"
            return v
        else:
            return raw_digits.rjust(4, self.MIDDLE_DOT)



from .. import Provider as AddressProvider


class Provider(AddressProvider):
    """
    Address Provider for the zu_ZA locale (Zulu, South Africa).

    Data sourced from:
    - South African cities and towns: https://en.wikipedia.org/wiki/List_of_cities_and_towns_in_South_Africa
    - South African postal codes: https://en.wikipedia.org/wiki/List_of_postal_codes_in_South_Africa
    - Languages of South Africa: https://en.wikipedia.org/wiki/Languages_of_South_Africa
    """

    city_formats = ("{{city_name}}",)
    building_number_formats = ("%#", "%##", "%###")
    postcode_formats = ("%###",)  # Güncellendi: 4 haneli posta kodu için
    section_formats = ("",)
    street_address_formats = ("{{building_number}} {{street_name}} {{street_suffix}}",)
    address_formats = ("{{street_address}}, {{city}}, {{postcode}}",)
    secondary_address_formats = ("Flat #%#", "Unit #%#", "Suite #%#")

    street_names = (
        "Main",
        "Church",
        "President",
        "Voortrekker",
        "Nelson Mandela",
        "Albertina Sisulu",
        "Rivonia",
        "Jan Smuts",
        "Commissioner",
        "Long",
        "High",
        "Short",
        "Victoria",
        "Queen",
        "King",
        "Oxford",
        "George",
        "William",
        "York",
        "Smith",
        "Adelaide",
        "Charles",
        "Churchill",
        "Cecil",
        "Clarence",
        "Edward",
        "Elizabeth",
        "Frere",
        "Gandhi",
        "Grey",
        "James",
        "Joseph",
        "Milner",
        "Napier",
        "Paul Kruger",
        "Prince",
        "Somerset",
        "Stanley",
        "Thomas",
        "Walter Sisulu",
        "West",
    )

    street_suffixes = ("Umgwaqo", "Indlela", "Isitaladi", "Ithafa", "Indawo")

    cities = (
        "eGoli",
        "eThekwini",
        "iBhayi",
        "iKapa",
        "uMgungundlovu",
        "Polokwane",
        "Mbombela",
        "Mahikeng",
        "Kimberley",
        "Bloemfontein",
        "Rustenburg",
        "Soweto",
        "Benoni",
        "Tembisa",
        "Welkom",
        "Vereeniging",
        "Chatsworth",
        "Uitenhage",
        "Middelburg",
        "Springs",
        "Randfontein",
        "Boksburg",
        "Witbank",
        "Klerksdorp",
        "Bethlehem",
        "George",
        "Upington",
        "Musina",
        "Vanderbijlpark",
        "Stellenbosch",
        "Krugersdorp",
        "Sasolburg",
        "Centurion",
        "Newcastle",
        "Thohoyandou",
        "Potchefstroom",
        "Kathu",
        "Paarl",
    )

    city_suffixes = ("",)

    countries = (
        "iNingizimu Afrika",
        "Botswana",
        "Lesotho",
        "Namibia",
        "Eswatini",
        "Zimbabwe",
        "Mozambique",
        "Angola",
        "Zambia",
        "Malawi",
        "Madagascar",
        "Tanzania",
        "Kenya",
        "Nigeria",
        "Ghana",
        "Egypt",
        "Morocco",
        "Tunisia",
        "Algeria",
        "Ethiopia",
        "Sudan",
        "Somalia",
        "Uganda",
        "Cameroon",
        "DR Congo",
        "Rwanda",
        "Burundi",
        "Senegal",
        "Mali",
        "Ivory Coast",
        "Niger",
        "Chad",
        "Mauritania",
        "Eritrea",
        "Djibouti",
        "Cape Verde",
        "Seychelles",
        "Mauritius",
        "Comoros",
        "Gambia",
        "Liberia",
        "Sierra Leone",
        "Benin",
        "Togo",
        "Equatorial Guinea",
        "Gabon",
        "Congo",
        "Central African Republic",
        "Sao Tome and Principe",
        "Guinea",
        "Guinea-Bissau",
        "Burkina Faso",
    )

    provinces = (
        "iMpuma-Kapa",
        "Freistata",
        "eGoli",
        "iKwaZulu-Natali",
        "Limpopo",
        "iMpumalanga",
        "Bokone Bophirima",
        "Noord-Kaap",
        "Wes-Kaap",
    )

    def secondary_address(self) -> str:
        """
        :sample:
        """
        return self.numerify(self.random_element(self.secondary_address_formats))

    def building_number(self) -> str:
        """
        :sample:
        """
        return self.numerify(self.random_element(self.building_number_formats))

    def street_name(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.street_names)

    def street_suffix(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.street_suffixes)

    def city_name(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.cities)

    def city_name_suffix(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.city_suffixes)

    def section_number(self) -> str:
        """
        :sample:
        """
        return self.numerify(self.random_element(self.section_formats))

    def province(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.provinces)

    def administrative_unit(self) -> str:
        """
        :sample:
        """
        return self.random_element(self.provinces)



from .. import ElementsType
from .. import Provider as PassportProvider


class Provider(PassportProvider):
    """Implement passport provider for ``it_IT``.

    Sources:

    - https://www.poliziadistato.it/articolo/10301
    - https://www.poliziadistato.it/statics/32/note_tecniche.pdf
    """

    electronic_passport_number_formats: ElementsType[str] = (
        # standard passaporto elettronico (elettronic passport)
        # Format: 2 letters, 7 digits (e.g., YA1234567), used from 2010 on
        "??#######",
    )

    def passport_number(self) -> str:
        """
        Generate a valid Italian passport number

        The format consist in 2 uppercase letters followed by 7 digits.
        """

        # select the passport number format
        format = self.random_element(self.electronic_passport_number_formats)

        return self.bothify(format).upper()



import string

from datetime import datetime, timedelta

from .. import BaseProvider, ElementsType

_DT_ALMOST_MAX = datetime.max - timedelta(1.0)


class Provider(BaseProvider):
    """Implement default user agent provider for Faker."""

    user_agents: ElementsType[str] = (
        "chrome",
        "firefox",
        "internet_explorer",
        "opera",
        "safari",
    )

    # source
    # https://en.wikipedia.org/wiki/Microsoft_Windows
    windows_platform_tokens: ElementsType[str] = (
        "Windows 95",
        "Windows 98",
        "Windows 98; Win 9x 4.90",
        "Windows CE",
        "Windows NT 4.0",
        "Windows NT 5.0",
        "Windows NT 5.01",
        "Windows NT 5.1",
        "Windows NT 5.2",
        "Windows NT 6.0",
        "Windows NT 6.1",
        "Windows NT 6.2",
        "Windows NT 10.0",
        "Windows NT 11.0",
    )

    linux_processors: ElementsType[str] = ("i686", "x86_64")

    mac_processors: ElementsType[str] = ("Intel", "PPC", "U; Intel", "U; PPC")

    # source
    # https://en.wikipedia.org/wiki/Android_version_history
    android_versions: ElementsType[str] = (
        "1.0",
        "1.1",
        "1.5",
        "1.6",
        "2.0",
        "2.0.1",
        "2.1",
        "2.2",
        "2.2.1",
        "2.2.2",
        "2.2.3",
        "2.3",
        "2.3.1",
        "2.3.2",
        "2.3.3",
        "2.3.4",
        "2.3.5",
        "2.3.6",
        "2.3.7",
        "3.0",
        "3.1",
        "3.2",
        "3.2.1",
        "3.2.2",
        "3.2.3",
        "3.2.4",
        "3.2.5",
        "3.2.6",
        "4.0",
        "4.0.1",
        "4.0.2",
        "4.0.3",
        "4.0.4",
        "4.1",
        "4.1.1",
        "4.1.2",
        "4.2",
        "4.2.1",
        "4.2.2",
        "4.3",
        "4.3.1",
        "4.4",
        "4.4.1",
        "4.4.2",
        "4.4.3",
        "4.4.4",
        "5.0",
        "5.0.1",
        "5.0.2",
        "5.1",
        "5.1.1",
        "6.0",
        "6.0.1",
        "7.0",
        "7.1",
        "7.1.1",
        "7.1.2",
        "8.0.0",
        "8.1.0",
        "9",
        "10",
        "11",
        "12",
        "12.1",
        "13",
        "14",
    )

    apple_devices: ElementsType[str] = ("iPhone", "iPad")

    # sources
    # https://en.wikipedia.org/wiki/IOS_version_history
    ios_versions: ElementsType[str] = (
        "1.1.5",
        "2.2.1",
        "3.1.3",
        "3.2.2",
        "4.2.1",
        "4.3.5",
        "5.1.1",
        "6.1.6",
        "7.1.2",
        "8.4.1",
        "9.3.5",
        "9.3.6",
        "10.3.3",
        "10.3.4",
        "11.4.1",
        "12.4.4",
        "12.4.8",
        "12.5.7",
        "13.5.1",
        "13.7",
        "14.2",
        "14.2.1",
        "14.8.1",
        "15.8.2",
        "16.7.6",
        "16.7.7",
        "17.1",
        "17.1.1",
        "17.1.2",
        "17.2",
        "17.2.1",
        "17.3",
        "17.3.1",
        "17.4",
        "17.4.1",
    )

    def mac_processor(self) -> str:
        """Generate a MacOS processor token used in user agent strings."""
        return self.random_element(self.mac_processors)

    def linux_processor(self) -> str:
        """Generate a Linux processor token used in user agent strings."""
        return self.random_element(self.linux_processors)

    def user_agent(self) -> str:
        """Generate a random web browser user agent string."""
        name: str = self.random_element(self.user_agents)
        return getattr(self, name)()

    def chrome(
        self,
        version_from: int = 13,
        version_to: int = 63,
        build_from: int = 800,
        build_to: int = 899,
    ) -> str:
        """Generate a Chrome web browser user agent string."""
        saf: str = f"{self.generator.random.randint(531, 536)}.{self.generator.random.randint(0, 2)}"
        bld: str = self.lexify(self.numerify("##?###"), string.ascii_uppercase)
        tmplt: str = "({0}) AppleWebKit/{1} (KHTML, like Gecko) Chrome/{2}.0.{3}.0 Safari/{4}"
        tmplt_ios: str = "({0}) AppleWebKit/{1} (KHTML, like Gecko) CriOS/{2}.0.{3}.0 Mobile/{4} Safari/{1}"
        platforms: ElementsType[str] = (
            tmplt.format(
                self.linux_platform_token(),
                saf,
                self.generator.random.randint(version_from, version_to),
                self.generator.random.randint(build_from, build_to),
                saf,
            ),
            tmplt.format(
                self.windows_platform_token(),
                saf,
                self.generator.random.randint(version_from, version_to),
                self.generator.random.randint(build_from, build_to),
                saf,
            ),
            tmplt.format(
                self.mac_platform_token(),
                saf,
                self.generator.random.randint(version_from, version_to),
                self.generator.random.randint(build_from, build_to),
                saf,
            ),
            tmplt.format(
                f"Linux; {self.android_platform_token()}",
                saf,
                self.generator.random.randint(version_from, version_to),
                self.generator.random.randint(build_from, build_to),
                saf,
            ),
            tmplt_ios.format(
                self.ios_platform_token(),
                saf,
                self.generator.random.randint(version_from, version_to),
                self.generator.random.randint(build_from, build_to),
                bld,
            ),
        )

        return "Mozilla/5.0 " + self.random_element(platforms)

    def firefox(self) -> str:
        """Generate a Mozilla Firefox web browser user agent string."""
        ver: ElementsType[str] = (
            (
                f"Gecko/{self.generator.date_time_between(datetime(2011, 1, 1), _DT_ALMOST_MAX)} "
                f"Firefox/{self.generator.random.randint(4, 15)}.0"
            ),
            (
                f"Gecko/{self.generator.date_time_between(datetime(2010, 1, 1), _DT_ALMOST_MAX)} "
                f"Firefox/3.6.{self.generator.random.randint(1, 20)}"
            ),
            f"Gecko/{self.generator.date_time_between(datetime(2010, 1, 1), _DT_ALMOST_MAX)} Firefox/3.8",
        )
        tmplt_win: str = "({0}; {1}; rv:1.9.{2}.20) {3}"
        tmplt_lin: str = "({0}; rv:1.9.{1}.20) {2}"
        tmplt_mac: str = "({0}; rv:1.9.{1}.20) {2}"
        tmplt_and: str = "({0}; Mobile; rv:{1}.0) Gecko/{1}.0 Firefox/{1}.0"
        tmplt_ios: str = "({0}) AppleWebKit/{1} (KHTML, like Gecko) FxiOS/{2}.{3}.0 Mobile/{4} Safari/{1}"
        saf: str = f"{self.generator.random.randint(531, 536)}.{self.generator.random.randint(0, 2)}"
        bld: str = self.lexify(self.numerify("##?###"), string.ascii_uppercase)
        bld2: str = self.lexify(self.numerify("#?####"), string.ascii_lowercase)
        platforms: ElementsType[str] = (
            tmplt_win.format(
                self.windows_platform_token(),
                self.generator.locale().replace("_", "-"),
                self.generator.random.randint(0, 2),
                self.generator.random.choice(ver),
            ),
            tmplt_lin.format(
                self.linux_platform_token(),
                self.generator.random.randint(5, 7),
                self.generator.random.choice(ver),
            ),
            tmplt_mac.format(
                self.mac_platform_token(),
                self.generator.random.randint(2, 6),
                self.generator.random.choice(ver),
            ),
            tmplt_and.format(self.android_platform_token(), self.generator.random.randint(5, 68)),
            tmplt_ios.format(
                self.ios_platform_token(),
                saf,
                self.generator.random.randint(9, 18),
                bld2,
                bld,
            ),
        )

        return "Mozilla/5.0 " + self.random_element(platforms)

    def safari(self) -> str:
        """Generate a Safari web browser user agent string."""
        saf: str = (
            f"{self.generator.random.randint(531, 535)}."
            f"{self.generator.random.randint(1, 50)}."
            f"{self.generator.random.randint(1, 7)}"
        )

        ver: str = (
            f"{self.generator.random.randint(4, 5)}.{self.generator.random.randint(0, 1)}"
            if not self.generator.random.getrandbits(1)
            else f"{self.generator.random.randint(4, 5)}.0.{self.generator.random.randint(1, 5)}"
        )

        tmplt_win: str = "(Windows; U; {0}) AppleWebKit/{1} (KHTML, like Gecko) Version/{2} Safari/{3}"
        tmplt_mac: str = "({0} rv:{1}.0; {2}) AppleWebKit/{3} (KHTML, like Gecko) Version/{4} Safari/{5}"
        tmplt_ipod: str = (
            "(iPod; U; CPU iPhone OS {0}_{1} like Mac OS X; {2})"
            " AppleWebKit/{3} (KHTML, like Gecko) Version/{4}.0.5"
            " Mobile/8B{5} Safari/6{6}"
        )
        locale: str = self.generator.locale().replace("_", "-")
        platforms: ElementsType[str] = (
            tmplt_win.format(self.windows_platform_token(), saf, ver, saf),
            tmplt_mac.format(
                self.mac_platform_token(),
                self.generator.random.randint(2, 6),
                locale,
                saf,
                ver,
                saf,
            ),
            tmplt_ipod.format(
                self.generator.random.randint(3, 4),
                self.generator.random.randint(0, 3),
                locale,
                saf,
                self.generator.random.randint(3, 4),
                self.generator.random.randint(111, 119),
                saf,
            ),
        )

        return "Mozilla/5.0 " + self.random_element(platforms)

    def opera(self) -> str:
        """Generate an Opera web browser user agent string."""
        token: str = (
            self.linux_platform_token() if self.generator.random.getrandbits(1) else self.windows_platform_token()
        )
        locale: str = self.generator.locale().replace("_", "-")
        platform: str = (
            f"({token}; {locale}) Presto/2.9.{self.generator.random.randint(160, 190)} "
            f"Version/{self.generator.random.randint(10, 12)}.00"
        )
        return f"Opera/{self.generator.random.randint(8, 9)}.{self.generator.random.randint(10, 99)}.{platform}"

    def internet_explorer(self) -> str:
        """Generate an IE web browser user agent string."""
        return (
            f"Mozilla/5.0 (compatible; MSIE {self.generator.random.randint(5, 9)}.0; "
            f"{self.windows_platform_token()}; "
            f"Trident/{self.generator.random.randint(3, 5)}.{self.generator.random.randint(0, 1)})"
        )

    def windows_platform_token(self) -> str:
        """Generate a Windows platform token used in user agent strings."""
        return self.random_element(self.windows_platform_tokens)

    def linux_platform_token(self) -> str:
        """Generate a Linux platform token used in user agent strings."""
        return f"X11; Linux {self.random_element(self.linux_processors)}"

    def mac_platform_token(self) -> str:
        """Generate a MacOS platform token used in user agent strings."""
        return (
            f"Macintosh; {self.random_element(self.mac_processors)} Mac OS X 10_"
            f"{self.generator.random.randint(5, 12)}_{self.generator.random.randint(0, 9)}"
        )

    def android_platform_token(self) -> str:
        """Generate an Android platform token used in user agent strings."""
        return f"Android {self.random_element(self.android_versions)}"

    def ios_platform_token(self) -> str:
        """Generate an iOS platform token used in user agent strings."""
        apple_device: str = self.random_element(self.apple_devices)
        ios_version: str = self.random_element(self.ios_versions)
        return f"{apple_device}; CPU {apple_device} " f'OS {ios_version.replace(".", "_")} like Mac OS X'



from collections import OrderedDict
from string import ascii_uppercase

from .. import Provider as AutomotiveProvider


class Provider(AutomotiveProvider):
    """Implement automotive provider for ``es_AR`` locale.

    Sources:

    - https://en.wikipedia.org/wiki/Vehicle_registration_plates_of_Argentina

    """

    license_plate_old_format_first_letter = ascii_uppercase.replace("YZ", "")

    license_plate_new_first_letter = OrderedDict(
        [
            ("A", 0.99),
            ("B", 0.001),
            ("C", 0.0001),
            ("D", 0.00001),
            ("E", 0.0000000001),
        ]
    )

    license_plate_new_second_letter = OrderedDict(
        [
            ("A", 0.1),
            ("B", 0.1),
            ("C", 0.1),
            ("D", 0.1),
            ("E", 0.1),
            ("F", 0.1),
            ("G", 0.09),
            ("H", 0.08),
            ("I", 0.07),
            ("J", 0.06),
            ("K", 0.04),
            ("L", 0.03),
            ("M", 0.009),
            ("N", 0.007),
            ("O", 0.005),
            ("P", 0.004),
            ("Q", 0.001),
            ("R", 0.0009),
            ("S", 0.0008),
            ("T", 0.0007),
            ("U", 0.0006),
            ("V", 0.0005),
            ("W", 0.0003),
            ("X", 0.0002),
            ("Y", 0.0001),
            ("Z", 0.00005),
        ]
    )

    license_formats = OrderedDict(
        [
            ("{{license_plate_old}}", 0.6),
            ("{{license_plate_mercosur}}", 0.4),
        ]
    )

    def license_plate_old(self) -> str:
        """Generate an old format license plate. Since 1995 to 2016"""
        format = "??###"

        first_letter: str = self.random_element(self.license_plate_old_format_first_letter)

        return self.bothify(first_letter + format).upper()

    def license_plate_mercosur(self) -> str:
        """Generate an new plate with Mercosur format. Since 2016"""

        first_letter: str = self.random_element(self.license_plate_new_first_letter)
        second_letter: str = self.random_element(self.license_plate_new_second_letter)

        format = "###??"
        plate = first_letter + second_letter

        return self.bothify(plate + format).upper()

    def license_plate(self) -> str:
        """Generate a license plate."""
        return self.numerify(self.generator.parse(self.random_element(self.license_formats)))



from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    """Phone number provider for `de_CH` locale.

    Sources:
    - https://de.wikipedia.org/wiki/Telefonnummer_(Schweiz)

    """

    dialing_codes = (
        "75",
        "76",
        "77",
        "78",
        "79",
    )

    landline_codes = (
        "21",
        "22",
        "24",
        "26",
        "27",
        "31",
        "32",
        "33",
        "34",
        "43",
        "41",
        "44",
        "52",
        "55",
        "56",
        "61",
        "62",
        "71",
        "81",
        "91",
    )

    cellphone_formats = (
        "+41 {{dialing_code}} ### ## ##",
        "0{{dialing_code}} ### ## ##",
    )

    landline_formats = (
        "+41 {{landline_code}} ### ## ##",
        "0{{landline_code}} ### ## ##",
    )

    """
        Get dialing code for cellphone numbers.
    """

    def dialing_code(self) -> str:
        return self.random_element(self.dialing_codes)

    """
        Get dialing code for landlines.
    """

    def landline_code(self) -> str:
        return self.random_element(self.landline_codes)

    """
        Get a landline phone number.
    """

    def phone_number(self) -> str:
        pattern: str = self.random_element(self.landline_formats)
        return self.numerify(self.generator.parse(pattern))

    """
        Get a cellphone number.
    """

    def cellphone_number(self) -> str:
        pattern: str = self.random_element(self.cellphone_formats)
        return self.numerify(self.generator.parse(pattern))



from collections import OrderedDict

from .. import Provider as ColorProvider

localized = True


class Provider(ColorProvider):
    """
    Implement color provider for ``el_GR`` locale.
    Naming and hex codes are based on https://encycolorpedia.gr/named
    """

    all_colors = OrderedDict(
        (
            ("άσιντ πράσινο", "#B0BF1A"),
            ("άσπρο", "#FFFFFF"),
            ("άστριοι", "#FDD5B1"),
            ("αβοκάντο", "#568203"),
            ("αγκινάρα", "#8F9779"),
            ("αζούρ", "#8AB9F1"),
            ("ακαζού", "#4C2F27"),
            ("ασημένιο", "#C0C0C0"),
            ("βαθύ κόκκινο", "#850101"),
            ("βερικοκί", "#FBCEB1"),
            ("βερμιγιόν", "#E34234"),
            ("βιολετί", "#7F00FF"),
            ("βρύο", "#8A9A5B"),
            ("βυσσινί", "#DC143C"),
            ("γαλάζιο", "#ADD8E6"),
            ("γκρι", "#808080"),
            ("γλαυκό", "#6082B6"),
            ("εκρού", "#C2B280"),
            ("ιβουάρ", "#FFFFF0"),
            ("ινδικό", "#4B0082"),
            ("κίτρινο", "#9B870C"),
            ("καμηλό", "#C19A6B"),
            ("κανέλα", "#D2691E"),
            ("καστανέρυθρο", "#8B0000"),
            ("καστανό", "#954535"),
            ("καφέ", "#A52A2A"),
            ("καφές", "#6F4E37"),
            ("κυανό", "#800080"),
            ("κεχριμπάρι", "#FFBF00"),
            ("κόκκινο", "#FF0000"),
            ("λάβα", "#CF1020"),
            ("λαδί", "#3B3C36"),
            ("λευκό", "#DBE9F4"),
            ("μαρόν", "#800000"),
            ("ματζέντα", "#CC00CC"),
            ("μαόνι", "#CD4A4C"),
            ("μαύρο", "#000000"),
            ("μπέιμπι μπλου", "#89CFF0"),
            ("μπεζ", "#F5F5DC"),
            ("μπλε", "#0000FF"),
            ("μπλε μαρέν", "#1974D2"),
            ("μπορντό", "#7F1734"),
            ("μπουργκουντί", "#900020"),
            ("μυρτιά", "#317873"),
            ("μωβ", "#B19CD9"),
            ("ορείχαλκος", "#B5A642"),
            ("πέρλα", "#EAE0C8"),
            ("πεύκο", "#01796F"),
            ("πλατίνα", "#E5E4E2"),
            ("πορτοκαλί", "#FF7F00"),
            ("πορτοκαλοκίτρινο", "#DAA520"),
            ("πράσινο", "#000FF0"),
            ("πράσινο chartreuse", "#7FFF00"),
            ("πράσινο αγκινάρας", "#4B6F44"),
            ("πράσινο ανοιχτό", "#90EE90"),
            ("πράσινο ζούγκλας", "#29AB87"),
            ("πράσινο λαουρέλ", "#A9BA9D"),
            ("πράσινο σκούρο", "#013220"),
            ("πράσινο της άνοιξης", "#00FF7F"),
            ("πράσινο της μέντας", "#98FB98"),
            ("πράσινο της φτέρης", "#4F7942"),
            ("πράσινο του δάσους", "#228B22"),
            ("πράσινο τσάι", "#D0F0C0"),
            ("πράσινο χούκερ", "#49796B"),
            ("ραφ", "#5D8AA8"),
            ("ροζ", "#FFC0CB"),
            ("ροζέ", "#FF007F"),
            ("σέπια", "#704214"),
            ("σαμπανιζέ", "#F7E7CE"),
            ("σκάρλετ", "#FF2400"),
            ("σκούρο βρύο", "#4A5D23"),
            ("σπαραγγί", "#87A96B"),
            ("ταν", "#D2B48C"),
            ("φλαμίνγκο", "#FC8EAC"),
            ("φούξια", "#F400A1"),
            ("φτέρη", "#71BC78"),
            ("χλωροφύλλη", "#4AFF00"),
            ("χρυσαφένιο", "#FFD700"),
            ("χρυσό", "#808000"),
            ("ώχρα", "#E97451"),
        )
    )

    safe_colors = (
        "μαύρο",
        "πράσινο",
        "μπλε",
        "κίτρινο",
        "κόκκινο",
        "μωβ",
        "άσπρο",
        "γκρι",
        "ασημένιο",
        "καφέ",
        "λαδί",
        "χρυσό",
        "ροζ",
    )
